@@ -962,7 +962,7 @@ static BOOL expand_env_to_command(ALLOC char** result, char* str, sCommand* comm
             /// block ///
             else {
                 int rcode;
-                sObject* nextout = FD_NEW_STACK(kFDKindBuf, 0);
+                sObject* nextout = FD_NEW_STACK();
 
                 if(!run(env->mBlock, nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject))
                 {
@@ -986,9 +986,9 @@ static BOOL expand_env_to_command(ALLOC char** result, char* str, sCommand* comm
                     fd_split(nextout, env->mLineField);
                     
                     int i;
-                    for(i=0; i<vector_count(SFD(nextout).fdbuf.mLines); i++) 
+                    for(i=0; i<vector_count(SFD(nextout).mLines); i++) 
                     {
-                        char* item = vector_item(SFD(nextout).fdbuf.mLines, i);
+                        char* item = vector_item(SFD(nextout).mLines, i);
                         sObject* item2 = STRING_NEW_STACK(item);
                         string_chomp(item2);
 
@@ -998,7 +998,7 @@ static BOOL expand_env_to_command(ALLOC char** result, char* str, sCommand* comm
                     }
                 }
                 else {
-                    add_str_to_buf(&buf, SFD(nextout).fdbuf.mBuf, SFD(nextout).fdbuf.mBufLen);
+                    add_str_to_buf(&buf, SFD(nextout).mBuf, SFD(nextout).mBufLen);
                 }
             }
         }
@@ -1310,8 +1310,8 @@ int block_gc_children_mark(sObject* self)
             for(k=0; k<SBLOCK(self).mStatments[i].mCommands[j].mBlocksNum; k++) 
             {
                 sObject* block = SBLOCK(self).mStatments[i].mCommands[j].mBlocks[k];
-                if((block->mFlg & GC_MARK) == 0) {
-                    block->mFlg |= GC_MARK;
+                if(IS_MARKED(block) == 0) {
+                    SET_MARK(block);
                     count++;
                     count += block_gc_children_mark(block);
                 }
@@ -1319,8 +1319,8 @@ int block_gc_children_mark(sObject* self)
             for(k=0; k<SBLOCK(self).mStatments[i].mCommands[j].mEnvsNum; k++) {
                 if(SBLOCK(self).mStatments[i].mCommands[j].mEnvs[k].mKind == kEnvBlock) {
                     sObject* block = SBLOCK(self).mStatments[i].mCommands[j].mEnvs[k].mBlock;
-                    if((block->mFlg & GC_MARK) == 0) {
-                        block->mFlg |= GC_MARK;
+                    if(IS_MARKED(block) == 0) {
+                        SET_MARK(block);
                         count++;
                         count += block_gc_children_mark(block);
                     }
@@ -1355,7 +1355,7 @@ void sCommand_add_env(sCommand* self, MANAGED char* name, MANAGED char* key, BOO
     self->mEnvsNum++;
 }
 
-void sCommand_add_env_block(sCommand* self, sObject* block, BOOL double_dollar, enum eLineField lf)
+void sCommand_add_env_block(sCommand* self, sObject* block, BOOL double_dollar, eLineField lf)
 {
     if(self->mEnvsNum >= self->mEnvsSize) {
         if(self->mEnvs == NULL) {
