@@ -141,8 +141,8 @@ int class_gc_children_mark(sObject* self)
 
     sObject* block = SCLASS(self).mBlock;
     if(block) {
-        if((block->mFlg & GC_MARK) == 0) {
-            block->mFlg |= GC_MARK;
+        if(IS_MARKED(block) == 0) {
+            SET_MARK(block);
             count++;
             count += object_gc_children_mark(block);
         }
@@ -150,8 +150,8 @@ int class_gc_children_mark(sObject* self)
 
     sObject* parent = SCLASS(self).mParent;
     if(parent) {
-        if((parent->mFlg & GC_MARK) == 0) {
-            parent->mFlg |= GC_MARK;
+        if(IS_MARKED(parent) == 0) {
+            SET_MARK(parent);
             count++;
             count += object_gc_children_mark(parent);
         }
@@ -159,8 +159,8 @@ int class_gc_children_mark(sObject* self)
 
     sObject* lobjects = SCLASS(self).mLocalObjects;
     if(lobjects) {
-        if((lobjects->mFlg & GC_MARK) == 0) {
-            lobjects->mFlg |= GC_MARK;
+        if(IS_MARKED(lobjects) == 0) {
+            SET_MARK(lobjects);
             count++;
             count += object_gc_children_mark(lobjects);
         }
@@ -168,8 +168,8 @@ int class_gc_children_mark(sObject* self)
 
     sObject* arg_blocks = SCLASS(self).mArgBlocks;
     if(arg_blocks) {
-        if((arg_blocks->mFlg & GC_MARK) == 0) {
-            arg_blocks->mFlg |= GC_MARK;
+        if(IS_MARKED(arg_blocks) == 0) {
+            SET_MARK(arg_blocks);
             count++;
             count += object_gc_children_mark(arg_blocks);
         }
