@@ -28,7 +28,7 @@ BOOL cmd_each(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     sCommand* command = runinfo->mCommand;
 
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
     }
@@ -47,7 +47,7 @@ BOOL cmd_each(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         char* argument;
         if(argument = sCommand_option_with_argument_item(command, "-number")) {
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -56,16 +56,16 @@ BOOL cmd_each(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             int number = atoi(argument);
 
-            sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+            sObject* nextin2 = FD_NEW_STACK();
 
             int i;
-            for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i+=number) {
+            for(i=0; i<vector_count(SFD(nextin).mLines); i+=number) {
                 fd_clear(nextin2);
 
                 int j;
-                for(j=0; j<number && i+j<vector_count(SFD(nextin).fdbuf.mLines); j++)
+                for(j=0; j<number && i+j<vector_count(SFD(nextin).mLines); j++)
                 {
-                    char* str = vector_item(SFD(nextin).fdbuf.mLines, i+j);
+                    char* str = vector_item(SFD(nextin).mLines, i+j);
                     if(!fd_write(nextin2, str, strlen(str))) {
                         err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -89,20 +89,20 @@ BOOL cmd_each(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
         else {
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
                 runinfo->mRCode = 0;
             }
 
-            sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+            sObject* nextin2 = FD_NEW_STACK();
 
             int i;
-            for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
+            for(i=0; i<vector_count(SFD(nextin).mLines); i++) {
                 fd_clear(nextin2);
 
-                char* str = vector_item(SFD(nextin).fdbuf.mLines, i);
+                char* str = vector_item(SFD(nextin).mLines, i);
 
                 if(!fd_write(nextin2, str, strlen(str))) {
                     err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
@@ -134,7 +134,7 @@ BOOL cmd_join(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     sCommand* command = runinfo->mCommand;
 
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
     }
@@ -159,10 +159,10 @@ BOOL cmd_join(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             field = " ";
         }
 
-        if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
+        if(vector_count(SFD(nextin).mLines) > 0) {
             int i;
-            for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines)-1; i++) {
-                sObject* line = STRING_NEW_STACK(vector_item(SFD(nextin).fdbuf.mLines, i));
+            for(i=0; i<vector_count(SFD(nextin).mLines)-1; i++) {
+                sObject* line = STRING_NEW_STACK(vector_item(SFD(nextin).mLines, i));
                 string_chomp(line);
                 if(!fd_write(nextout, string_c_str(line), string_length(line))) {
                     err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
@@ -176,7 +176,7 @@ BOOL cmd_join(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
             }
 
-            sObject* line = STRING_NEW_STACK(vector_item(SFD(nextin).fdbuf.mLines, i));
+            sObject* line = STRING_NEW_STACK(vector_item(SFD(nextin).mLines, i));
             string_chomp(line);
             if(!fd_write(nextout, string_c_str(line), string_length(line))) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
@@ -191,7 +191,7 @@ BOOL cmd_join(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -206,7 +206,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     sCommand* command = runinfo->mCommand;
 
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
     }
@@ -221,7 +221,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
 
     if(command->mArgsNumRuntime > 1 && command->mBlocksNum <= command->mArgsNumRuntime-1 && runinfo->mFilter) {
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -230,7 +230,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         fd_split(nextin, lf);
 
-        if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
+        if(vector_count(SFD(nextin).mLines) > 0) {
             int i;
             for(i=1; i<command->mArgsNumRuntime; i++) {
                 char* arg = command->mArgsRuntime[i];
@@ -256,30 +256,30 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     int second = atoi(buf2);
 
                     if(first < 0) {
-                        first += vector_count(SFD(nextin).fdbuf.mLines);
+                        first += vector_count(SFD(nextin).mLines);
                         if(first < 0) first = 0;
                     }
                     if(second < 0) {
-                        second += vector_count(SFD(nextin).fdbuf.mLines);
+                        second += vector_count(SFD(nextin).mLines);
                         if(second < 0) second = 0;
                     }
-                    if(first >= vector_count(SFD(nextin).fdbuf.mLines)) {
-                        first = vector_count(SFD(nextin).fdbuf.mLines) -1;
+                    if(first >= vector_count(SFD(nextin).mLines)) {
+                        first = vector_count(SFD(nextin).mLines) -1;
                         if(first < 0) first = 0;
                     }
-                    if(second >= vector_count(SFD(nextin).fdbuf.mLines)) {
-                        second = vector_count(SFD(nextin).fdbuf.mLines) -1;
+                    if(second >= vector_count(SFD(nextin).mLines)) {
+                        second = vector_count(SFD(nextin).mLines) -1;
                         if(second < 0) second = 0;
                     }
 
                     if(first < second) {
-                        sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+                        sObject* nextin2 = FD_NEW_STACK();
 
                         int j;
                         for(j=first; j<=second; j++) {
                             fd_clear(nextin2);
 
-                            char* str = vector_item(SFD(nextin).fdbuf.mLines, j);
+                            char* str = vector_item(SFD(nextin).mLines, j);
                             if(!fd_write(nextin2,str,strlen(str))) {
                                 err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -295,7 +295,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                                 runinfo->mRCode = rcode;
                             }
                             else {
-                                if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen))
+                                if(!fd_write(nextout, SFD(nextin2).mBuf, SFD(nextin2).mBufLen))
                                 {
                                     err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -306,13 +306,13 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         }
                     }
                     else {
-                        sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+                        sObject* nextin2 = FD_NEW_STACK();
 
                         int j;
                         for(j=first; j>=second; j--) {
                             fd_clear(nextin2);
 
-                            char* str = vector_item(SFD(nextin).fdbuf.mLines, j);
+                            char* str = vector_item(SFD(nextin).mLines, j);
                             if(!fd_write(nextin2, str, strlen(str))) {
                                 err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -329,7 +329,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                                 runinfo->mRCode = rcode;
                             }
                             else {
-                                if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen))
+                                if(!fd_write(nextout, SFD(nextin2).mBuf, SFD(nextin2).mBufLen))
                                 {
                                     err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -345,17 +345,17 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     int num = atoi(arg);
 
                     if(num < 0) {
-                        num += vector_count(SFD(nextin).fdbuf.mLines);
+                        num += vector_count(SFD(nextin).mLines);
                         if(num < 0) num = 0;
                     }
-                    if(num >= vector_count(SFD(nextin).fdbuf.mLines)) {
-                        num = vector_count(SFD(nextin).fdbuf.mLines) -1;
+                    if(num >= vector_count(SFD(nextin).mLines)) {
+                        num = vector_count(SFD(nextin).mLines) -1;
                         if(num < 0) num = 0;
                     }
 
-                    sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+                    sObject* nextin2 = FD_NEW_STACK();
 
-                    char* str = vector_item(SFD(nextin).fdbuf.mLines, num);
+                    char* str = vector_item(SFD(nextin).mLines, num);
                     if(!fd_write(nextin2, str, strlen(str))){
                         err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -372,7 +372,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         runinfo->mRCode = rcode;
                     }
                     else {
-                        if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen))
+                        if(!fd_write(nextout, SFD(nextin2).mBuf, SFD(nextin2).mBufLen))
                         {
                             err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -548,7 +548,7 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     sCommand* command = runinfo->mCommand;
 
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
     }
@@ -566,23 +566,23 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         if(sCommand_option_item(command, "-shuffle")) {
             fd_split(nextin, lf);
 
-            if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
-                int* shuffle_num = MALLOC(sizeof(int)*vector_count(SFD(nextin).fdbuf.mLines));
+            if(vector_count(SFD(nextin).mLines) > 0) {
+                int* shuffle_num = MALLOC(sizeof(int)*vector_count(SFD(nextin).mLines));
                 int i;
-                for(i=0;i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
+                for(i=0;i<vector_count(SFD(nextin).mLines); i++) {
                     shuffle_num[i] = rand() % 2560;
                 }
 
-                sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
-                if(!vector_sort_cancelable_shuffle(SFD(nextin).fdbuf.mLines, sort_fun_shuffle, shuffle_num)) {
+                sObject* nextin2 = FD_NEW_STACK();
+                if(!vector_sort_cancelable_shuffle(SFD(nextin).mLines, sort_fun_shuffle, shuffle_num)) {
                     FREE(shuffle_num);
                     return FALSE;
                 }
 
                 FREE(shuffle_num);
 
-                for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
-                    char* line = vector_item(SFD(nextin).fdbuf.mLines, i);
+                for(i=0; i<vector_count(SFD(nextin).mLines); i++) {
+                    char* line = vector_item(SFD(nextin).mLines, i);
                     if(!fd_write(nextout, line, strlen(line))) {
                         err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -591,7 +591,7 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
             }
 
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -601,15 +601,15 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         else if(command->mBlocksNum == 1) {
             fd_split(nextin, lf);
 
-            if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
-                sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
-                if(!vector_sort_cancelable(SFD(nextin).fdbuf.mLines, sort_fun, runinfo, nextin2, nextout)) {
+            if(vector_count(SFD(nextin).mLines) > 0) {
+                sObject* nextin2 = FD_NEW_STACK();
+                if(!vector_sort_cancelable(SFD(nextin).mLines, sort_fun, runinfo, nextin2, nextout)) {
                     return FALSE;
                 }
 
                 int i;
-                for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
-                    char* line = vector_item(SFD(nextin).fdbuf.mLines, i);
+                for(i=0; i<vector_count(SFD(nextin).mLines); i++) {
+                    char* line = vector_item(SFD(nextin).mLines, i);
                     if(!fd_write(nextout, line, strlen(line))) {
                         err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -617,7 +617,7 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     }
                 }
             }
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
