@@ -270,7 +270,7 @@ BOOL cmd_print(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
     else if(runinfo->mFilter) {
         if(sCommand_option_item(command, "-read-from-error")) {
-            if(!fd_write(out, SFD(gStderr).fdbuf.mBuf, SFD(gStderr).fdbuf.mBufLen)) {
+            if(!fd_write(out, SFD(gStderr).mBuf, SFD(gStderr).mBufLen)) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
@@ -278,14 +278,14 @@ BOOL cmd_print(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             fd_clear(gStderr);
         }
         else {
-            if(!fd_write(out, SFD(nextin).fdbuf.mBuf, SFD(nextin).fdbuf.mBufLen)) {
+            if(!fd_write(out, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -377,7 +377,12 @@ BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             sObject* item = uobject_item(current_object, var_name);
 
-            if(item && item->mUserObject) {
+            if(!IS_USER_OBJECT(item)) {
+                err_msg("it's not user object. can't delete", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                return FALSE;
+            }
+
+            if(item) {
                 if(item != gCurrentObject || strcmp(var_name, SUOBJECT(item).mName) != 0) {
                     if(uobject_erase(current_object, var_name)) {
                         runinfo->mRCode = 0;
@@ -443,7 +448,7 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         runinfo->mRCode = rcode;
     }
     else if(runinfo->mFilter) {
-        char* buf = SFD(nextin).fdbuf.mBuf;
+        char* buf = SFD(nextin).mBuf;
 
         stack_start_stack();
         int rcode = 0;
@@ -453,7 +458,7 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         snprintf(buf2, BUFSIZ, "%s %d: eval", runinfo->mSName, runinfo->mSLine);
 
         if(parse(buf, buf2, &sline, block, NULL)) {
-            sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+            sObject* nextin2 = FD_NEW_STACK();
             if(!run(block, nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                 err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = rcode;
@@ -469,7 +474,7 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         stack_end_stack();
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -544,7 +549,7 @@ BOOL cmd_stackframe(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         char* key = uobject_loop_key(it);
 
         char*obj_kind[16] = {
-            NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "job", "object", "memchecker", "function", "class", "external program", "completion", "external object"
+            NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "job", "object", "function", "class", "external program", "completion", "external object"
         };
         int size = snprintf(buf, BUFSIZ, "%s: %s\n", key, obj_kind[TYPE(object2)]);
 
@@ -571,8 +576,9 @@ BOOL cmd_funinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     sObject* running_object = runinfo->mRunningObject;
 
-    if(running_object && (TYPE(running_object) == T_FUN || TYPE(running_object) == T_CLASS) && SFUN(running_object).mRunInfo) {
-        sRunInfo* runinfo2 = SFUN(running_object).mRunInfo;
+    if(running_object && (TYPE(running_object) == T_FUN || TYPE(running_object) == T_CLASS) && gRunInfoOfRunningObject)
+    {
+        sRunInfo* runinfo2 = gRunInfoOfRunningObject;
 
         char buf[BUFSIZ];
         sObject* object;
