@@ -31,7 +31,7 @@ BOOL cmd_condition_n(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(SFD(nextin).fdbuf.mBufLen > 0) {
+        if(SFD(nextin).mBufLen > 0) {
             runinfo->mRCode = 0;
         }
     }
@@ -45,7 +45,7 @@ BOOL cmd_condition_z(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = 0;
         }
     }
@@ -60,7 +60,7 @@ BOOL cmd_condition_b(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(S_ISBLK(stat_.st_mode)) {
                 runinfo->mRCode = 0;
             }
@@ -77,7 +77,7 @@ BOOL cmd_condition_c(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(S_ISCHR(stat_.st_mode)) {
                 runinfo->mRCode = 0;
             }
@@ -94,7 +94,7 @@ BOOL cmd_condition_d(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(S_ISDIR(stat_.st_mode)) {
                 runinfo->mRCode = 0;
             }
@@ -111,7 +111,7 @@ BOOL cmd_condition_f(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(S_ISREG(stat_.st_mode)) {
                 runinfo->mRCode = 0;
             }
@@ -128,7 +128,7 @@ BOOL cmd_condition_h(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(S_ISLNK(stat_.st_mode)) {
                 runinfo->mRCode = 0;
             }
@@ -145,7 +145,7 @@ BOOL cmd_condition_l(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(S_ISLNK(stat_.st_mode)) {
                 runinfo->mRCode = 0;
             }
@@ -162,7 +162,7 @@ BOOL cmd_condition_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(S_ISFIFO(stat_.st_mode)) {
                 runinfo->mRCode = 0;
             }
@@ -185,7 +185,7 @@ BOOL cmd_condition_s2(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(S_ISSOCK(stat_.st_mode)) {
                 runinfo->mRCode = 0;
             }
@@ -202,7 +202,7 @@ BOOL cmd_condition_g(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(stat_.st_mode & S_ISGID) {
                 runinfo->mRCode = 0;
             }
@@ -219,7 +219,7 @@ BOOL cmd_condition_k(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
 #if defined(S_ISTXT)
             if(stat_.st_mode & S_ISTXT) {
                 runinfo->mRCode = 0;
@@ -243,7 +243,7 @@ BOOL cmd_condition_u(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(stat_.st_mode & S_ISUID) {
                 runinfo->mRCode = 0;
             }
@@ -259,7 +259,7 @@ BOOL cmd_condition_r(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(access(SFD(nextin).fdbuf.mBuf, R_OK) == 0) {
+        if(access(SFD(nextin).mBuf, R_OK) == 0) {
             runinfo->mRCode = 0;
         }
     }
@@ -273,7 +273,7 @@ BOOL cmd_condition_w(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(access(SFD(nextin).fdbuf.mBuf, W_OK) == 0) {
+        if(access(SFD(nextin).mBuf, W_OK) == 0) {
             runinfo->mRCode = 0;
         }
     }
@@ -287,7 +287,7 @@ BOOL cmd_condition_x(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(access(SFD(nextin).fdbuf.mBuf, X_OK) == 0) {
+        if(access(SFD(nextin).mBuf, X_OK) == 0) {
             runinfo->mRCode = 0;
         }
     }
@@ -302,7 +302,7 @@ BOOL cmd_condition_o(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(stat_.st_uid == getuid()) {
                 runinfo->mRCode = 0;
             }
@@ -319,7 +319,7 @@ BOOL cmd_condition_g2(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(stat_.st_gid == getgid()) {
                 runinfo->mRCode = 0;
             }
@@ -336,7 +336,7 @@ BOOL cmd_condition_e(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             runinfo->mRCode = 0;
         }
     }
@@ -351,7 +351,7 @@ BOOL cmd_condition_s(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat stat_;
-        if(stat(SFD(nextin).fdbuf.mBuf, &stat_) == 0) {
+        if(stat(SFD(nextin).mBuf, &stat_) == 0) {
             if(stat_.st_size > 0) {
                 runinfo->mRCode = 0;
             }
@@ -368,12 +368,12 @@ BOOL cmd_condition_eq(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         if(sCommand_option_item(command, "-ignore-case")) {
-            if(strcasecmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) == 0) {
+            if(strcasecmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) == 0) {
                 runinfo->mRCode = 0;
             }
         }
         else {
-            if(strcmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) == 0) {
+            if(strcmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) == 0) {
                 runinfo->mRCode = 0;
             }
         }
@@ -389,12 +389,12 @@ BOOL cmd_condition_neq(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         if(sCommand_option_item(command, "-ignore-case")) {
-            if(strcasecmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) != 0) {
+            if(strcasecmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) != 0) {
                 runinfo->mRCode = 0;
             }
         }
         else {
-            if(strcmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) != 0) {
+            if(strcmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) != 0) {
                 runinfo->mRCode = 0;
             }
         }
@@ -410,12 +410,12 @@ BOOL cmd_condition_slt(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         if(sCommand_option_item(command, "-ignore-case")) {
-            if(strcasecmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) < 0) {
+            if(strcasecmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) < 0) {
                 runinfo->mRCode = 0;
             }
         }
         else {
-            if(strcmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) < 0) {
+            if(strcmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) < 0) {
                 runinfo->mRCode = 0;
             }
         }
@@ -431,12 +431,12 @@ BOOL cmd_condition_sgt(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         if(sCommand_option_item(command, "-ignore-case")) {
-            if(strcasecmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) > 0) {
+            if(strcasecmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) > 0) {
                 runinfo->mRCode = 0;
             }
         }
         else {
-            if(strcmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) > 0) {
+            if(strcmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) > 0) {
                 runinfo->mRCode = 0;
             }
         }
@@ -452,12 +452,12 @@ BOOL cmd_condition_sle(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         if(sCommand_option_item(command, "-ignore-case")) {
-            if(strcasecmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) <= 0) {
+            if(strcasecmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) <= 0) {
                 runinfo->mRCode = 0;
             }
         }
         else {
-            if(strcmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) <= 0) {
+            if(strcmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) <= 0) {
                 runinfo->mRCode = 0;
             }
         }
@@ -473,12 +473,12 @@ BOOL cmd_condition_sge(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
         if(sCommand_option_item(command, "-ignore-case")) {
-            if(strcasecmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) >= 0) {
+            if(strcasecmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) >= 0) {
                 runinfo->mRCode = 0;
             }
         }
         else {
-            if(strcmp(SFD(nextin).fdbuf.mBuf, command->mArgsRuntime[1]) >= 0) {
+            if(strcmp(SFD(nextin).mBuf, command->mArgsRuntime[1]) >= 0) {
                 runinfo->mRCode = 0;
             }
         }
@@ -493,7 +493,7 @@ BOOL cmd_condition_eq2(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(atoi(SFD(nextin).fdbuf.mBuf) == atoi(command->mArgsRuntime[1])) {
+        if(atoi(SFD(nextin).mBuf) == atoi(command->mArgsRuntime[1])) {
             runinfo->mRCode = 0;
         }
     }
@@ -507,7 +507,7 @@ BOOL cmd_condition_ne(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(atoi(SFD(nextin).fdbuf.mBuf) != atoi(command->mArgsRuntime[1])) {
+        if(atoi(SFD(nextin).mBuf) != atoi(command->mArgsRuntime[1])) {
             runinfo->mRCode = 0;
         }
     }
@@ -521,7 +521,7 @@ BOOL cmd_condition_lt(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(atoi(SFD(nextin).fdbuf.mBuf) < atoi(command->mArgsRuntime[1])) {
+        if(atoi(SFD(nextin).mBuf) < atoi(command->mArgsRuntime[1])) {
             runinfo->mRCode = 0;
         }
     }
@@ -535,7 +535,7 @@ BOOL cmd_condition_le(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(atoi(SFD(nextin).fdbuf.mBuf) <= atoi(command->mArgsRuntime[1])) {
+        if(atoi(SFD(nextin).mBuf) <= atoi(command->mArgsRuntime[1])) {
             runinfo->mRCode = 0;
         }
     }
@@ -549,7 +549,7 @@ BOOL cmd_condition_gt(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(atoi(SFD(nextin).fdbuf.mBuf) > atoi(command->mArgsRuntime[1])) {
+        if(atoi(SFD(nextin).mBuf) > atoi(command->mArgsRuntime[1])) {
             runinfo->mRCode = 0;
         }
     }
@@ -563,7 +563,7 @@ BOOL cmd_condition_ge(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        if(atoi(SFD(nextin).fdbuf.mBuf) >= atoi(command->mArgsRuntime[1])) {
+        if(atoi(SFD(nextin).mBuf) >= atoi(command->mArgsRuntime[1])) {
             runinfo->mRCode = 0;
         }
     }
@@ -579,7 +579,7 @@ BOOL cmd_condition_nt(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat lstat_;
         struct stat rstat_;
-        if(lstat(SFD(nextin).fdbuf.mBuf, &lstat_) == 0) {
+        if(lstat(SFD(nextin).mBuf, &lstat_) == 0) {
             if(lstat(command->mArgsRuntime[1], &rstat_) == 0) {
                 if(lstat_.st_mtime > rstat_.st_mtime) 
                 {
@@ -600,7 +600,7 @@ BOOL cmd_condition_ot(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         runinfo->mRCode = RCODE_NFUN_FALSE;
         struct stat lstat_;
         struct stat rstat_;
-        if(lstat(SFD(nextin).fdbuf.mBuf, &lstat_) == 0) {
+        if(lstat(SFD(nextin).mBuf, &lstat_) == 0) {
             if(lstat(command->mArgsRuntime[1], &rstat_) == 0) {
                 if(lstat_.st_mtime < rstat_.st_mtime) 
                 {
@@ -673,7 +673,7 @@ BOOL cmd_condition_re(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         //BOOL preserve = sCommand_option_item(command, "-preserve");
 
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        char* target = SFD(nextin).fdbuf.mBuf;
+        char* target = SFD(nextin).mBuf;
         char* regex = command->mArgsRuntime[1];
 
         regex_t* reg;
@@ -835,7 +835,7 @@ BOOL cmd_migemo_match(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
         runinfo->mRCode = RCODE_NFUN_FALSE;
-        char* target = SFD(nextin).fdbuf.mBuf;
+        char* target = SFD(nextin).mBuf;
         char* regex = command->mArgsRuntime[1];
 
         if(regex[0] == 0) {
