@@ -92,7 +92,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         return FALSE;
     }
 
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
     }
@@ -126,7 +126,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         fd_split(nextin, lf);
 
-        if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
+        if(vector_count(SFD(nextin).mLines) > 0) {
             msave_ttysettings();
             msave_screen();
             initscr();
@@ -136,8 +136,8 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             const int maxx = mgetmaxx();
             const int maxy = mgetmaxy();
 
-            int* markfiles = MALLOC(sizeof(int)*vector_count(SFD(nextin).fdbuf.mLines));
-            memset(markfiles, 0, sizeof(int)*vector_count(SFD(nextin).fdbuf.mLines));
+            int* markfiles = MALLOC(sizeof(int)*vector_count(SFD(nextin).mLines));
+            memset(markfiles, 0, sizeof(int)*vector_count(SFD(nextin).mLines));
 
             static int scrolltop = 0;
             static int cursor = 0;
@@ -150,15 +150,15 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             if(cursor < 0) {
                 cursor = 0;
             }
-            if(cursor >= vector_count(SFD(nextin).fdbuf.mLines)) {
-                cursor = vector_count(SFD(nextin).fdbuf.mLines)-1;
+            if(cursor >= vector_count(SFD(nextin).mLines)) {
+                cursor = vector_count(SFD(nextin).mLines)-1;
                 if(cursor < 0) cursor = 0;
             }
             if(cursor < scrolltop) {
                 int i = cursor;
                 int width_sum = 0;
                 while(width_sum < maxy) {
-                    char* line = vector_item(SFD(nextin).fdbuf.mLines, i);
+                    char* line = vector_item(SFD(nextin).mLines, i);
                     int width = str_termlen(code, line) / maxx + 1;
                     width_sum += width;
                     i--;
@@ -176,7 +176,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 clear();
                 int n = scrolltop;
                 int y = 0;
-                while(y < maxy && n < vector_count(SFD(nextin).fdbuf.mLines)) {
+                while(y < maxy && n < vector_count(SFD(nextin).mLines)) {
                     int attrs = 0;
                     if(n == cursor) {
                         attrs = A_REVERSE;
@@ -186,7 +186,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     }
                     if(attrs) attron(attrs);
 
-                    char* line = vector_item(SFD(nextin).fdbuf.mLines, n);
+                    char* line = vector_item(SFD(nextin).mLines, n);
 
                     if(str_termlen(code, line) <= maxx) {
                         mvprintw(y, 0, "%s", line);
@@ -239,7 +239,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
                 else if(key == 'a' && multiple) {
                     int i;
-                    for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
+                    for(i=0; i<vector_count(SFD(nextin).mLines); i++) {
                         markfiles[i] = !markfiles[i];
                     }
                 }
@@ -251,9 +251,9 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     if(multiple) {
                         BOOL flg_mark = FALSE;
                         int k;
-                        for(k=0; k<vector_count(SFD(nextin).fdbuf.mLines); k++) {
+                        for(k=0; k<vector_count(SFD(nextin).mLines); k++) {
                             if(markfiles[k]) {
-                                char* str = vector_item(SFD(nextin).fdbuf.mLines, k);
+                                char* str = vector_item(SFD(nextin).mLines, k);
                                 if(!fd_write(nextout,str, strlen(str))) {
                                     err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -266,7 +266,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         }
 
                         if(!flg_mark) {
-                            char* str = vector_item(SFD(nextin).fdbuf.mLines, cursor);
+                            char* str = vector_item(SFD(nextin).mLines, cursor);
                             if(!fd_write(nextout, str, strlen(str))) {
                                 err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -276,7 +276,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         }
                     }
                     else {
-                        char* str = vector_item(SFD(nextin).fdbuf.mLines, cursor);
+                        char* str = vector_item(SFD(nextin).mLines, cursor);
                         if(!fd_write(nextout, str, strlen(str))) {
                             err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -284,7 +284,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                             return FALSE;
                         }
                     }
-                    if(SFD(nextin).fdbuf.mBufLen == 0) {
+                    if(SFD(nextin).mBufLen == 0) {
                         runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                     }
                     else {
@@ -296,8 +296,8 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 if(cursor < 0) {
                     cursor = 0;
                 }
-                if(cursor >= vector_count(SFD(nextin).fdbuf.mLines)) {
-                    cursor = vector_count(SFD(nextin).fdbuf.mLines)-1;
+                if(cursor >= vector_count(SFD(nextin).mLines)) {
+                    cursor = vector_count(SFD(nextin).mLines)-1;
                     if(cursor < 0) cursor = 0;
                 }
                 if(cursor >= n) {
@@ -307,7 +307,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     int i = cursor;
                     int width_sum = 0;
                     while(width_sum < maxy) {
-                        char* line = vector_item(SFD(nextin).fdbuf.mLines, i);
+                        char* line = vector_item(SFD(nextin).mLines, i);
                         int width = str_termlen(code, line) / maxx + 1;
                         width_sum += width;
                         i--;
@@ -353,7 +353,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         return FALSE;
     }
 
-    enum eLineField lf = kLF;
+    eLineField lf = kLF;
 
     enum eKanjiCode code = gKanjiCode;
     if(sCommand_option_item(command, "-byte")) {
@@ -370,11 +370,11 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
 
     if(runinfo->mFilter) {
-        sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+        sObject* nextin2 = FD_NEW_STACK();
 
         /// make control characters visible ///
-        char* p = SFD(nextin).fdbuf.mBuf;
-        while(p - SFD(nextin).fdbuf.mBuf < SFD(nextin).fdbuf.mBufLen) {
+        char* p = SFD(nextin).mBuf;
+        while(p - SFD(nextin).mBuf < SFD(nextin).mBufLen) {
             if(*p == '\n') {
                 if(!fd_writec(nextin2, *p)) {
                     err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
@@ -418,8 +418,8 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         const int maxx = mgetmaxx();
         const int maxy = mgetmaxy();
 
-        int* markfiles = MALLOC(sizeof(int)*vector_count(SFD(nextin2).fdbuf.mLines));
-        memset(markfiles, 0, sizeof(int)*vector_count(SFD(nextin2).fdbuf.mLines));
+        int* markfiles = MALLOC(sizeof(int)*vector_count(SFD(nextin2).mLines));
+        memset(markfiles, 0, sizeof(int)*vector_count(SFD(nextin2).mLines));
 
         static int scrolltop = 0;
         static int cursor = 0;
@@ -432,15 +432,15 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         if(cursor < 0) {
             cursor = 0;
         }
-        if(cursor >= vector_count(SFD(nextin2).fdbuf.mLines)) {
-            cursor = vector_count(SFD(nextin2).fdbuf.mLines)-1;
+        if(cursor >= vector_count(SFD(nextin2).mLines)) {
+            cursor = vector_count(SFD(nextin2).mLines)-1;
             if(cursor < 0) cursor = 0;
         }
         if(cursor < scrolltop) {
             int i = cursor;
             int width_sum = 0;
             while(width_sum < maxy) {
-                char* line = vector_item(SFD(nextin2).fdbuf.mLines, i);
+                char* line = vector_item(SFD(nextin2).mLines, i);
                 int width = str_termlen(code, line) / maxx + 1;
                 width_sum += width;
                 i--;
@@ -458,7 +458,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             clear();
             int n = scrolltop;
             int y = 0;
-            while(y < maxy && n < vector_count(SFD(nextin2).fdbuf.mLines)) {
+            while(y < maxy && n < vector_count(SFD(nextin2).mLines)) {
                 int attrs = 0;
                 if(n == cursor) {
                     attrs = A_REVERSE;
@@ -468,7 +468,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
                 if(attrs) attron(attrs);
 
-                char* line = vector_item(SFD(nextin2).fdbuf.mLines, n);
+                char* line = vector_item(SFD(nextin2).mLines, n);
 
                 if(str_termlen(code, line) <= maxx) {
                     mvprintw(y, 0, "%s", line);
@@ -520,13 +520,13 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 return FALSE;
             }
             else if(key == 10 || key == 13) {
-                if(!fd_write(nextout, SFD(nextin).fdbuf.mBuf, SFD(nextin).fdbuf.mBufLen)) {
+                if(!fd_write(nextout, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
                     err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     FREE(markfiles);
                     return FALSE;
                 }
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -538,8 +538,8 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             if(cursor < 0) {
                 cursor = 0;
             }
-            if(cursor >= vector_count(SFD(nextin2).fdbuf.mLines)) {
-                cursor = vector_count(SFD(nextin2).fdbuf.mLines)-1;
+            if(cursor >= vector_count(SFD(nextin2).mLines)) {
+                cursor = vector_count(SFD(nextin2).mLines)-1;
                 if(cursor < 0) cursor = 0;
             }
             if(cursor >= n) {
@@ -549,7 +549,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 int i = cursor;
                 int width_sum = 0;
                 while(width_sum < maxy) {
-                    char* line = vector_item(SFD(nextin2).fdbuf.mLines, i);
+                    char* line = vector_item(SFD(nextin2).mLines, i);
                     int width = str_termlen(code, line) / maxx + 1;
                     width_sum += width;
                     i--;
