@@ -48,21 +48,21 @@ BOOL cmd_write(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
 
         if(sCommand_option_item(command, "-error")) {
-            if(!bufsiz_write(fd, SFD(gStderr).fdbuf.mBuf, SFD(gStderr).fdbuf.mBufLen)) {
+            if(!bufsiz_write(fd, SFD(gStderr).mBuf, SFD(gStderr).mBufLen)) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             fd_clear(gStderr);
 
-            if(!fd_write(nextout, SFD(nextin).fdbuf.mBuf, SFD(nextin).fdbuf.mBufLen)) {
+            if(!fd_write(nextout, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
         }
         else {
-            if(!bufsiz_write(fd, SFD(nextin).fdbuf.mBuf, SFD(nextin).fdbuf.mBufLen)) {
+            if(!bufsiz_write(fd, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
@@ -71,7 +71,7 @@ BOOL cmd_write(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         (void)close(fd);
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
