@@ -82,7 +82,7 @@ BOOL cmd_plus(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     /// output
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
-        char* arg = SFD(nextin).fdbuf.mBuf;
+        char* arg = SFD(nextin).mBuf;
         int num = atoi(arg);
 
         num += atoi(command->mArgsRuntime[1]);
@@ -96,7 +96,7 @@ BOOL cmd_plus(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -113,7 +113,7 @@ BOOL cmd_minus(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     /// output
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
-        char* arg = SFD(nextin).fdbuf.mBuf;
+        char* arg = SFD(nextin).mBuf;
         int num = atoi(arg);
 
         num -= atoi(command->mArgsRuntime[1]);
@@ -127,7 +127,7 @@ BOOL cmd_minus(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -144,7 +144,7 @@ BOOL cmd_mult(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     /// output
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
-        char* arg = SFD(nextin).fdbuf.mBuf;
+        char* arg = SFD(nextin).mBuf;
         int num = atoi(arg);
 
         num *= atoi(command->mArgsRuntime[1]);
@@ -158,7 +158,7 @@ BOOL cmd_mult(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -175,7 +175,7 @@ BOOL cmd_div(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     /// output
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
-        char* arg = SFD(nextin).fdbuf.mBuf;
+        char* arg = SFD(nextin).mBuf;
         int num = atoi(arg);
 
         int num2 = atoi(command->mArgsRuntime[1]);
@@ -196,7 +196,7 @@ BOOL cmd_div(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -213,7 +213,7 @@ BOOL cmd_mod(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     /// output
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
-        char* arg = SFD(nextin).fdbuf.mBuf;
+        char* arg = SFD(nextin).mBuf;
         int num = atoi(arg);
 
         num = num % atoi(command->mArgsRuntime[1]);
@@ -227,7 +227,7 @@ BOOL cmd_mod(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -244,7 +244,7 @@ BOOL cmd_pow(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     /// output
     if(runinfo->mFilter && command->mArgsNumRuntime == 2) {
-        char* arg = SFD(nextin).fdbuf.mBuf;
+        char* arg = SFD(nextin).mBuf;
         int num = atoi(arg);
 
         num = pow(num, atoi(command->mArgsRuntime[1]));
@@ -258,7 +258,7 @@ BOOL cmd_pow(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -275,7 +275,7 @@ BOOL cmd_abs(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     /// output
     if(runinfo->mFilter) {
-        char* arg = SFD(nextin).fdbuf.mBuf;
+        char* arg = SFD(nextin).mBuf;
         int num = abs(atoi(arg));
 
         char buf[128];
@@ -287,7 +287,7 @@ BOOL cmd_abs(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
