@@ -35,8 +35,8 @@ BOOL cmd_mshow(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         char* key = uobject_loop_key(it);
 
         char buf[BUFSIZ];
-        char*obj_kind[16] = {
-            NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "job", "object", "memchecker", "function", "class", "external program", "completion", "external object"
+        char*obj_kind[T_TYPE_MAX] = {
+            NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "file dicriptor2", "job", "object", "function", "class", "external program", "completion", "external object"
         };
         int size = snprintf(buf, BUFSIZ, "%s: %s\n", key, obj_kind[TYPE(object2)]);
 
@@ -153,7 +153,7 @@ BOOL cmd_def(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             int rcode = 0;
             sObject* block = BLOCK_NEW_STACK();
             int sline = 1;
-            if(!parse(SFD(nextin).fdbuf.mBuf, "def", &sline, block, NULL)) {
+            if(!parse(SFD(nextin).mBuf, "def", &sline, block, NULL)) {
                 err_msg("parser error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 stack_end_stack();
                 return FALSE;
@@ -165,7 +165,7 @@ BOOL cmd_def(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
             stack_end_stack();
             
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -221,7 +221,7 @@ BOOL cmd_class(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             int rcode = 0;
             sObject* block = BLOCK_NEW_STACK();
             int sline = 1;
-            if(!parse(SFD(nextin).fdbuf.mBuf, "def", &sline, block, NULL)) {
+            if(!parse(SFD(nextin).mBuf, "def", &sline, block, NULL)) {
                 err_msg("parser error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 stack_end_stack();
                 return FALSE;
@@ -233,7 +233,7 @@ BOOL cmd_class(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
             stack_end_stack();
             
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -369,7 +369,7 @@ BOOL cmd_var(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
 
     char* field = "\n";
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
         field = "\r\n";
@@ -401,8 +401,129 @@ BOOL cmd_var(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         code = kEucjp;
     }
 
-    /// output
-    if(!runinfo->mFilter) {
+    /// input
+    if(runinfo->mFilter) {
+        fd_split(nextin, lf);
+
+        if(sCommand_option_item(command, "-new")) {
+            int max = vector_count(SFD(nextin).mLines);
+            if(max > 0) {
+                sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).mLines, 0), TRUE);
+                string_chomp(new_var);
+
+                if(!add_object_to_objects_in_pipe(new_var, runinfo, command))
+                {
+                    return FALSE;
+                }
+
+                char buf[128];
+                int size = snprintf(buf, 128, "%p", new_var);
+                if(!fd_write(nextout, buf, size)) {
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                    return FALSE;
+                }
+                if(!fd_write(nextout, "\n", 1)) {
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                    return FALSE;
+                }
+            }
+            else {
+                sObject* new_var = STRING_NEW_GC("", TRUE);
+
+                if(!add_object_to_objects_in_pipe(new_var, runinfo, command))
+                {
+                    return FALSE;
+                }
+
+                char buf[128];
+                int size = snprintf(buf, 128, "%p", new_var);
+                if(!fd_write(nextout, buf, size)) {
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                    return FALSE;
+                }
+                if(!fd_write(nextout, "\n", 1)) {
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                    return FALSE;
+                }
+            }
+
+            if(sCommand_option_item(command, "-shift")) {
+                int i;
+                for(i=1;i<max; i++) {
+                    char* str = vector_item(SFD(nextin).mLines, i);
+                    if(!fd_write(nextout, str, strlen(str))) {
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                        return FALSE;
+                    }
+                }
+            }
+
+            if(SFD(nextin).mBufLen == 0) {
+                runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
+            }
+            else {
+                runinfo->mRCode = 0;
+            }
+        }
+        else if(command->mArgsNumRuntime > 1) {
+            sObject* object;
+            if(sCommand_option_item(command, "-local")) {
+                object = SFUN(runinfo->mRunningObject).mLocalObjects;
+            }
+            else {
+                object = runinfo->mCurrentObject;
+            }
+
+            int i;
+            int max = vector_count(SFD(nextin).mLines);
+            for(i=1; i<command->mArgsNumRuntime; i++) {
+                sObject* current = runinfo->mCurrentObject;
+                sObject* tmp = access_object3(command->mArgsRuntime[i], &current);
+
+                if(tmp && sCommand_option_item(command, "-local") && !sCommand_option_item(command, "-force")) {
+                    err_msg("can't overwrite other the same name variable. Use -force option", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    return FALSE;
+                }
+
+                if(i-1 < max) {
+                    sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).mLines, i-1), TRUE);
+                    string_chomp(new_var);
+
+                    uobject_put(object, command->mArgsRuntime[i], new_var);
+                }
+                else {
+                    sObject* new_var = STRING_NEW_GC("", TRUE);
+
+                    uobject_put(object, command->mArgsRuntime[i], new_var);
+                }
+            }
+
+            if(sCommand_option_item(command, "-shift")) {
+                for(;i-1<max; i++) {
+                    char* str = vector_item(SFD(nextin).mLines, i-1);
+                    if(!fd_write(nextout, str, strlen(str))) {
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                        return FALSE;
+                    }
+                }
+            }
+
+            if(SFD(nextin).mBufLen == 0) {
+                runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
+            }
+            else {
+                runinfo->mRCode = 0;
+            }
+        }
+    }
+    /// output ///
+    else {
         if(command->mArgsNumRuntime > 1) {
             char* argument;
             if(argument = sCommand_option_with_argument_item(command, "-index")) {
@@ -474,127 +595,6 @@ BOOL cmd_var(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
     }
-    /// input ///
-    else {
-        fd_split(nextin, lf);
-
-        if(sCommand_option_item(command, "-new")) {
-            int max = vector_count(SFD(nextin).fdbuf.mLines);
-            if(max > 0) {
-                sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).fdbuf.mLines, 0), TRUE);
-                string_chomp(new_var);
-
-                if(!add_object_to_objects_in_pipe(new_var, runinfo, command))
-                {
-                    return FALSE;
-                }
-
-                char buf[128];
-                int size = snprintf(buf, 128, "%p", new_var);
-                if(!fd_write(nextout, buf, size)) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
-                    return FALSE;
-                }
-                if(!fd_write(nextout, "\n", 1)) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
-                    return FALSE;
-                }
-            }
-            else {
-                sObject* new_var = STRING_NEW_GC("", TRUE);
-
-                if(!add_object_to_objects_in_pipe(new_var, runinfo, command))
-                {
-                    return FALSE;
-                }
-
-                char buf[128];
-                int size = snprintf(buf, 128, "%p", new_var);
-                if(!fd_write(nextout, buf, size)) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
-                    return FALSE;
-                }
-                if(!fd_write(nextout, "\n", 1)) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
-                    return FALSE;
-                }
-            }
-
-            if(sCommand_option_item(command, "-shift")) {
-                int i;
-                for(i=1;i<max; i++) {
-                    char* str = vector_item(SFD(nextin).fdbuf.mLines, i);
-                    if(!fd_write(nextout, str, strlen(str))) {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                        runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
-                        return FALSE;
-                    }
-                }
-            }
-
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
-                runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
-            }
-            else {
-                runinfo->mRCode = 0;
-            }
-        }
-        else if(command->mArgsNumRuntime > 1) {
-            sObject* object;
-            if(sCommand_option_item(command, "-local")) {
-                object = SFUN(runinfo->mRunningObject).mLocalObjects;
-            }
-            else {
-                object = runinfo->mCurrentObject;
-            }
-
-            int i;
-            int max = vector_count(SFD(nextin).fdbuf.mLines);
-            for(i=1; i<command->mArgsNumRuntime; i++) {
-                sObject* current = runinfo->mCurrentObject;
-                sObject* tmp = access_object3(command->mArgsRuntime[i], &current);
-
-                if(tmp && sCommand_option_item(command, "-local") && !sCommand_option_item(command, "-force")) {
-                    err_msg("can't overwrite other the same name variable. Use -force option", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                    return FALSE;
-                }
-
-                if(i-1 < max) {
-                    sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).fdbuf.mLines, i-1), TRUE);
-                    string_chomp(new_var);
-
-                    uobject_put(object, command->mArgsRuntime[i], new_var);
-                }
-                else {
-                    sObject* new_var = STRING_NEW_GC("", TRUE);
-
-                    uobject_put(object, command->mArgsRuntime[i], new_var);
-                }
-            }
-
-            if(sCommand_option_item(command, "-shift")) {
-                for(;i-1<max; i++) {
-                    char* str = vector_item(SFD(nextin).fdbuf.mLines, i-1);
-                    if(!fd_write(nextout, str, strlen(str))) {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                        runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
-                        return FALSE;
-                    }
-                }
-            }
-
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
-                runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
-            }
-            else {
-                runinfo->mRCode = 0;
-            }
-        }
-    }
 
     return TRUE;
 }
@@ -604,7 +604,7 @@ BOOL cmd_ary(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
 
     char* field = "\n";
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
         field = "\r\n";
@@ -729,11 +729,12 @@ BOOL cmd_ary(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
     }
-    else if(sCommand_option_item(command, "-new")) {
+    else if(sCommand_option_item(command, "-new"))
+    {
         fd_split(nextin, lf);
 
         int i;
-        int max = vector_count(SFD(nextin).fdbuf.mLines);
+        int max = vector_count(SFD(nextin).mLines);
         sObject* new_ary = VECTOR_NEW_GC(16, TRUE);
 
         if(!add_object_to_objects_in_pipe(new_ary, runinfo, command))
@@ -755,12 +756,12 @@ BOOL cmd_ary(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
 
         for(i=0; i<max; i++) {
-            sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).fdbuf.mLines, i), FALSE);
+            sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).mLines, i), FALSE);
             string_chomp(new_var);
             vector_add(new_ary, new_var);
         }
         
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -789,17 +790,17 @@ BOOL cmd_ary(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             if(append > vector_count(ary)) append = vector_count(ary);
 
             int i;
-            int max = vector_count(SFD(nextin).fdbuf.mLines);
+            int max = vector_count(SFD(nextin).mLines);
             void** appended_ary = MALLOC(sizeof(sObject*)*max);
             for(i=0; i<max; i++) {
-                sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).fdbuf.mLines, i), FALSE);
+                sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).mLines, i), FALSE);
                 string_chomp(new_var);
                 appended_ary[i] = new_var;
             }
             vector_mass_insert(ary, append, appended_ary, max);
             FREE(appended_ary);
             
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -816,7 +817,7 @@ BOOL cmd_ary(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
 
             int i;
-            int max = vector_count(SFD(nextin).fdbuf.mLines);
+            int max = vector_count(SFD(nextin).mLines);
             sObject* new_ary = VECTOR_NEW_GC(16, TRUE);
 
             sObject* current = runinfo->mCurrentObject;
@@ -830,12 +831,12 @@ BOOL cmd_ary(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             uobject_put(object, command->mArgsRuntime[1], new_ary);
 
             for(i=0; i<max; i++) {
-                sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).fdbuf.mLines, i), FALSE);
+                sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).mLines, i), FALSE);
                 string_chomp(new_var);
                 vector_add(new_ary, new_var);
             }
             
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -852,7 +853,7 @@ BOOL cmd_hash(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
 
     char* field = "\n";
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
         field = "\r\n";
@@ -984,7 +985,7 @@ BOOL cmd_hash(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         fd_split(nextin, lf);
 
         int i;
-        int max = vector_count(SFD(nextin).fdbuf.mLines);
+        int max = vector_count(SFD(nextin).mLines);
         sObject* new_hash = HASH_NEW_GC(16, TRUE);
 
         if(!add_object_to_objects_in_pipe(new_hash, runinfo, command))
@@ -1008,17 +1009,17 @@ BOOL cmd_hash(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         sObject* key = STRING_NEW_STACK("");
         for(i=0; i<max; i++) {
             if((i % 2) == 0) {
-                string_put(key, vector_item(SFD(nextin).fdbuf.mLines, i));
+                string_put(key, vector_item(SFD(nextin).mLines, i));
                 string_chomp(key);
             }
             else {
-                sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).fdbuf.mLines, i), FALSE);
+                sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).mLines, i), FALSE);
                 string_chomp(new_var);
                 hash_put(new_hash, string_c_str(key), new_var);
             }
         }
             
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -1040,21 +1041,21 @@ BOOL cmd_hash(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
 
             int i;
-            int max = vector_count(SFD(nextin).fdbuf.mLines);
+            int max = vector_count(SFD(nextin).mLines);
             sObject* key = STRING_NEW_STACK("");
             for(i=0; i<max; i++) {
                 if((i % 2) == 0) {
-                    string_put(key, vector_item(SFD(nextin).fdbuf.mLines, i));
+                    string_put(key, vector_item(SFD(nextin).mLines, i));
                     string_chomp(key);
                 }
                 else {
-                    sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).fdbuf.mLines, i), FALSE);
+                    sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).mLines, i), FALSE);
                     string_chomp(new_var);
                     hash_put(hash, string_c_str(key), new_var);
                 }
             }
                 
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -1071,7 +1072,7 @@ BOOL cmd_hash(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
 
             int i;
-            int max = vector_count(SFD(nextin).fdbuf.mLines);
+            int max = vector_count(SFD(nextin).mLines);
             sObject* new_hash = HASH_NEW_GC(16, TRUE);
 
             sObject* current = runinfo->mCurrentObject;
@@ -1087,17 +1088,17 @@ BOOL cmd_hash(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             sObject* key = STRING_NEW_STACK("");
             for(i=0; i<max; i++) {
                 if((i % 2) == 0) {
-                    string_put(key, vector_item(SFD(nextin).fdbuf.mLines, i));
+                    string_put(key, vector_item(SFD(nextin).mLines, i));
                     string_chomp(key);
                 }
                 else {
-                    sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).fdbuf.mLines, i), FALSE);
+                    sObject* new_var = STRING_NEW_GC(vector_item(SFD(nextin).mLines, i), FALSE);
                     string_chomp(new_var);
                     hash_put(new_hash, string_c_str(key), new_var);
                 }
             }
                 
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -1302,7 +1303,7 @@ BOOL cmd_ref(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
 
     char* field = "\n";
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
         field = "\r\n";
@@ -1361,34 +1362,32 @@ BOOL cmd_ref(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         /// type
         if(sCommand_option_item(command, "-type")) {
             int i;
-            int max = vector_count(SFD(nextin).fdbuf.mLines);
+            int max = vector_count(SFD(nextin).mLines);
             for(i=0; i<max; i++) {
-                char* line = vector_item(SFD(nextin).fdbuf.mLines, i);
+                char* line = vector_item(SFD(nextin).mLines, i);
                 void* mem = (void*)(unsigned long)strtoll(line, NULL, 16);
-                if(mem == NULL) break;
-
-                int type = memchecker_item(gMemChecker, mem);
-
-                if(type >= 0) {
-                    char buf[128];
-                    char* obj_kind[16] = {
-                        NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "job", "object", "memchecker", "function", "class", "external program", "completion", "external object"
-                    };
-                    int size = snprintf(buf, 128, "%s\n", obj_kind[type]);
-
-                    if(!fd_write(nextout, buf, size)) {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                        runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
-                        return FALSE;
-                    }
+                if(mem == NULL || !gc_valid_object(mem) || !contained_in_pipe(mem)) {
+                    err_msg("invalid address. it's not memory managed by a xyzsh gabage collecter or it doesn't exist in pipe data", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    return FALSE;
                 }
-                else {
-                    err_msg("invalid adress. it's not memory managed by a xyzsh gabage collecter", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+
+                sObject* obj = mem;
+                int type = TYPE(obj);
+
+                char buf[128];
+                char* obj_kind[T_TYPE_MAX] = {
+                    NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "file dicriptor", "job", "object", "function", "class", "external program", "completion", "external object"
+                };
+                int size = snprintf(buf, 128, "%s\n", obj_kind[type]);
+
+                if(!fd_write(nextout, buf, size)) {
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
             }
 
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -1406,24 +1405,21 @@ BOOL cmd_ref(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
 
                 int i;
-                int max = vector_count(SFD(nextin).fdbuf.mLines);
+                int max = vector_count(SFD(nextin).mLines);
                 BOOL shift = sCommand_option_item(command, "-shift");
                 for(i=0; i<max; i++) {
                     if(i+1 < command->mArgsNumRuntime) {
-                        char* line = vector_item(SFD(nextin).fdbuf.mLines, i);
+                        char* line = vector_item(SFD(nextin).mLines, i);
                         void* mem = (void*)(unsigned long)strtoll(line, NULL, 16);
-                        int type = memchecker_item(gMemChecker, mem);
-
-                        if(type >= 0) {
-                            uobject_put(object, command->mArgsRuntime[i+1], mem);
-                        }
-                        else {
-                            err_msg("invalid adress. it's not memory managed by a xyzsh gabage collecter", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        if(mem == NULL || !gc_valid_object(mem) || !contained_in_pipe(mem)) {
+                            err_msg("invalid address. it's not memory managed by a xyzsh gabage collecter or it doesn't exist in pipe data", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                             return FALSE;
                         }
+
+                        uobject_put(object, command->mArgsRuntime[i+1], mem);
                     }
                     else if(shift) {
-                        char* str = vector_item(SFD(nextin).fdbuf.mLines, i);
+                        char* str = vector_item(SFD(nextin).mLines, i);
                         if(!fd_write(nextout, str, strlen(str))) {
                             err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -1435,7 +1431,7 @@ BOOL cmd_ref(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     }
                 }
 
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -1454,7 +1450,7 @@ BOOL cmd_export(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
 
     char* field = "\n";
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
         field = "\r\n";
@@ -1502,10 +1498,10 @@ BOOL cmd_export(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         if(command->mArgsNumRuntime > 1) {
             int i;
-            int max = vector_count(SFD(nextin).fdbuf.mLines);
+            int max = vector_count(SFD(nextin).mLines);
             for(i=1; i<command->mArgsNumRuntime; i++) {
                 if(i-1 < max) {
-                    sObject* new_var = STRING_NEW_STACK(vector_item(SFD(nextin).fdbuf.mLines, i-1));
+                    sObject* new_var = STRING_NEW_STACK(vector_item(SFD(nextin).mLines, i-1));
                     string_chomp(new_var);
                     setenv(command->mArgsRuntime[i], string_c_str(new_var), 1);
                 }
@@ -1516,7 +1512,7 @@ BOOL cmd_export(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             if(sCommand_option_item(command, "-shift")) {
                 for(;i-1<max; i++) {
-                    char* str = vector_item(SFD(nextin).fdbuf.mLines, i-1);
+                    char* str = vector_item(SFD(nextin).mLines, i-1);
                     if(!fd_write(nextout, str, strlen(str))) {
                         err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -1525,7 +1521,7 @@ BOOL cmd_export(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
             }
 
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
