@@ -100,7 +100,7 @@ BOOL cmd_quote(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     /// output
     if(runinfo->mFilter) {
-        char* p = SFD(nextin).fdbuf.mBuf;
+        char* p = SFD(nextin).mBuf;
         if(code == kByte) {
             while(*p) {
                 if(isalpha(*p)) {
@@ -189,7 +189,7 @@ BOOL cmd_quote(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -218,7 +218,7 @@ BOOL cmd_length(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         code = kEucjp;
     }
 
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
     }
@@ -237,7 +237,7 @@ BOOL cmd_length(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         /// line number
         if(sCommand_option_item(command, "-line-num")) {
             int result = 0;
-            char* p = SFD(nextin).fdbuf.mBuf;
+            char* p = SFD(nextin).mBuf;
             if(lf == kCRLF) {
                 while(1) {
                     if(*p == '\r' && *(p+1) == '\n') {
@@ -288,7 +288,7 @@ BOOL cmd_length(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
         else {
-            char* arg = SFD(nextin).fdbuf.mBuf;
+            char* arg = SFD(nextin).mBuf;
             int len = str_kanjilen(code, arg);
 
             char buf[128];
@@ -301,7 +301,7 @@ BOOL cmd_length(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -324,7 +324,7 @@ BOOL cmd_x(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             int i;
             for(i=0; i<multiple; i++) {
-                if(!fd_write(nextout, SFD(nextin).fdbuf.mBuf, SFD(nextin).fdbuf.mBufLen)) {
+                if(!fd_write(nextout, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
                     err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
@@ -332,7 +332,7 @@ BOOL cmd_x(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
 
 
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -365,7 +365,7 @@ BOOL cmd_index(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     /// output
     if(runinfo->mFilter) {
         if(command->mArgsNumRuntime == 2) {
-            char* target = SFD(nextin).fdbuf.mBuf;
+            char* target = SFD(nextin).mBuf;
 
             char* word = command->mArgsRuntime[1];
 
@@ -463,7 +463,7 @@ BOOL cmd_index(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 int c = str_pointer2kanjipos(code, target, result);
                 size = snprintf(msg, 64, "%d", c);
 
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -581,7 +581,7 @@ BOOL cmd_rindex(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     /// output
     if(runinfo->mFilter) {
         if(command->mArgsNumRuntime == 2) {
-            char* target = SFD(nextin).fdbuf.mBuf;
+            char* target = SFD(nextin).mBuf;
             char* word = command->mArgsRuntime[1];
 
             /// get starting point ///
@@ -682,7 +682,7 @@ BOOL cmd_rindex(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 int c = str_pointer2kanjipos(code, target, result);
                 size = snprintf(msg, 64, "%d", c);
 
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -728,7 +728,7 @@ BOOL cmd_lc(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
 
     if(runinfo->mFilter) {
-        sObject* str = STRING_NEW_STACK(SFD(nextin).fdbuf.mBuf);
+        sObject* str = STRING_NEW_STACK(SFD(nextin).mBuf);
         string_tolower(str, code);
 
         if(!fd_write(nextout, string_c_str(str), string_length(str))) {
@@ -737,7 +737,7 @@ BOOL cmd_lc(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -767,7 +767,7 @@ BOOL cmd_uc(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
 
     if(runinfo->mFilter) {
-        sObject* str = STRING_NEW_STACK(SFD(nextin).fdbuf.mBuf);
+        sObject* str = STRING_NEW_STACK(SFD(nextin).mBuf);
         string_toupper(str, code);
 
         if(!fd_write(nextout, string_c_str(str), string_length(str))) {
@@ -776,7 +776,7 @@ BOOL cmd_uc(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -792,9 +792,9 @@ BOOL cmd_chomp(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
 
     if(runinfo->mFilter) {
-        sObject* str = STRING_NEW_STACK(SFD(nextin).fdbuf.mBuf);
+        sObject* str = STRING_NEW_STACK(SFD(nextin).mBuf);
         if(string_chomp(str)) {
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -802,7 +802,7 @@ BOOL cmd_chomp(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
         else {
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -839,7 +839,7 @@ BOOL cmd_chop(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
 
     if(runinfo->mFilter) {
-        sObject* str = STRING_NEW_STACK(SFD(nextin).fdbuf.mBuf);
+        sObject* str = STRING_NEW_STACK(SFD(nextin).mBuf);
 
         if(code == kByte) {
             char* s = string_c_str(str);
@@ -849,7 +849,7 @@ BOOL cmd_chop(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             {
                 string_trunc(str, len-2);
 
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -859,7 +859,7 @@ BOOL cmd_chop(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             else if(len >= 1) {
                 string_trunc(str, len-1);
 
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -867,7 +867,7 @@ BOOL cmd_chop(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
             }
             else {
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -883,7 +883,7 @@ BOOL cmd_chop(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             string_erase(str, last_char_head-s, s + strlen(s) - last_char_head);
 
             if(len > 0) {
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -891,7 +891,7 @@ BOOL cmd_chop(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
             }
             else {
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -914,7 +914,7 @@ BOOL cmd_pomch(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     sCommand* command = runinfo->mCommand;
 
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
     }
@@ -929,9 +929,9 @@ BOOL cmd_pomch(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
 
     if(runinfo->mFilter) {
-        sObject* str = STRING_NEW_STACK(SFD(nextin).fdbuf.mBuf);
+        sObject* str = STRING_NEW_STACK(SFD(nextin).mBuf);
         if(string_pomch(str, lf)) {
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -939,7 +939,7 @@ BOOL cmd_pomch(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
         else {
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -961,7 +961,7 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     sCommand* command = runinfo->mCommand;
 
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
     }
@@ -1002,8 +1002,8 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         p++;
 
                         char* arg;
-                        if(strings_num < vector_count(SFD(nextin).fdbuf.mLines)) {
-                            arg = vector_item(SFD(nextin).fdbuf.mLines, strings_num);
+                        if(strings_num < vector_count(SFD(nextin).mLines)) {
+                            arg = vector_item(SFD(nextin).mLines, strings_num);
                         }
                         else {
                             arg = "0";
@@ -1027,8 +1027,8 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         p++;
 
                         char* arg;
-                        if(strings_num < vector_count(SFD(nextin).fdbuf.mLines)) {
-                            arg = vector_item(SFD(nextin).fdbuf.mLines, strings_num);
+                        if(strings_num < vector_count(SFD(nextin).mLines)) {
+                            arg = vector_item(SFD(nextin).mLines, strings_num);
                         }
                         else {
                             arg = "0";
@@ -1051,8 +1051,8 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         p++;
 
                         sObject* arg;
-                        if(strings_num < vector_count(SFD(nextin).fdbuf.mLines)) {
-                            arg = STRING_NEW_STACK(vector_item(SFD(nextin).fdbuf.mLines, strings_num));
+                        if(strings_num < vector_count(SFD(nextin).mLines)) {
+                            arg = STRING_NEW_STACK(vector_item(SFD(nextin).mLines, strings_num));
                         }
                         else {
                             arg = STRING_NEW_STACK("");
@@ -1086,8 +1086,8 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
 
-        if(strings_num > vector_count(SFD(nextin).fdbuf.mLines)) {
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(strings_num > vector_count(SFD(nextin).mLines)) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -1095,7 +1095,7 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
         else {
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -1120,8 +1120,8 @@ BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         if(command->mBlocksNum >= 1) {
             block = command->mBlocks[0];
-            nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
-            nextout2 = FD_NEW_STACK(kFDKindBuf, 0);
+            nextin2 = FD_NEW_STACK();
+            nextout2 = FD_NEW_STACK();
         }
         else {
             block = NULL;
@@ -1138,7 +1138,7 @@ BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int r = get_onig_regex(&reg, command, regex);
 
         if(r == ONIG_NORMAL) {
-           char* p = SFD(nextin).fdbuf.mBuf;
+           char* p = SFD(nextin).mBuf;
 
            sObject* sub_str = STRING_NEW_STACK("");
 
@@ -1146,7 +1146,7 @@ BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 OnigRegion* region = onig_region_new();
                 OnigErrorInfo err_info;
 
-                char* target = SFD(nextin).fdbuf.mBuf;
+                char* target = SFD(nextin).mBuf;
 
                 const int point = p - target;
                 int r2 = onig_search(reg, target
@@ -1231,7 +1231,7 @@ BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                             return FALSE;
                         }
 
-                        string_put(sub_str, SFD(nextout2).fdbuf.mBuf);
+                        string_put(sub_str, SFD(nextout2).mBuf);
                     }
                     else {
                         char* p2 = destination;
@@ -1361,7 +1361,7 @@ BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         uobject_put(gRootObject, "SUB_COUNT", STRING_NEW_GC(buf, FALSE));
 
         if(sub_count > 0) {
-            if(SFD(nextin).fdbuf.mBufLen == 0) {
+            if(SFD(nextin).mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
             else {
@@ -1400,7 +1400,7 @@ BOOL cmd_scan(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         if(command->mBlocksNum >= 1) {
             block = command->mBlocks[0];
-            nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+            nextin2 = FD_NEW_STACK();
         }
         else {
             block = NULL;
@@ -1413,9 +1413,9 @@ BOOL cmd_scan(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int r = get_onig_regex(&reg, command, regex);
 
         if(r == ONIG_NORMAL) {
-            char* target = SFD(nextin).fdbuf.mBuf;
-            char* p = SFD(nextin).fdbuf.mBuf;
-            char* end = SFD(nextin).fdbuf.mBuf + strlen(SFD(nextin).fdbuf.mBuf);
+            char* target = SFD(nextin).mBuf;
+            char* p = SFD(nextin).mBuf;
+            char* end = SFD(nextin).mBuf + strlen(SFD(nextin).mBuf);
             while(p < end) {
                 OnigRegion* region = onig_region_new();
                 int r2 = onig_search(reg, target
@@ -1587,7 +1587,7 @@ BOOL cmd_scan(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         }
                     }
 
-                    p = SFD(nextin).fdbuf.mBuf + region->end[0];
+                    p = SFD(nextin).mBuf + region->end[0];
                 }
                 else {
                     p++;
@@ -1603,7 +1603,7 @@ BOOL cmd_scan(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             uobject_put(gRootObject, "MATCH_COUNT", STRING_NEW_GC(buf, FALSE));
 
             if(match_count > 0) {
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -1624,7 +1624,7 @@ BOOL cmd_split(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
 
     char* field = "\n";
-    enum eLineField lf = gLineField;
+    eLineField lf = gLineField;
     if(sCommand_option_item(command, "-Lw")) {
         lf = kCRLF;
         field = "\r\n";
@@ -1671,7 +1671,7 @@ BOOL cmd_split(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         if(r == ONIG_NORMAL) {
             char* target;
-            char* p = target = SFD(nextin).fdbuf.mBuf;
+            char* p = target = SFD(nextin).mBuf;
 
             int split_count = 0;
 
@@ -1832,7 +1832,7 @@ BOOL cmd_split(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
 
             if(split_count > 0) {
-                if(SFD(nextin).fdbuf.mBufLen == 0) {
+                if(SFD(nextin).mBufLen == 0) {
                     runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
                 }
                 else {
@@ -1882,7 +1882,7 @@ BOOL cmd_add(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             number = -1;
         }
 
-        const int len = str_kanjilen(code, SFD(nextin).fdbuf.mBuf);
+        const int len = str_kanjilen(code, SFD(nextin).mBuf);
 
         if(number < 0) {
             number += len + 1;
@@ -1890,8 +1890,8 @@ BOOL cmd_add(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
 
         if(number < len) {
-            int point = str_kanjipos2pointer(code, SFD(nextin).fdbuf.mBuf, number) - SFD(nextin).fdbuf.mBuf;
-            if(!fd_write(nextout, SFD(nextin).fdbuf.mBuf, point)) {
+            int point = str_kanjipos2pointer(code, SFD(nextin).mBuf, number) - SFD(nextin).mBuf;
+            if(!fd_write(nextout, SFD(nextin).mBuf, point)) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
@@ -1901,14 +1901,14 @@ BOOL cmd_add(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
-            if(!fd_write(nextout, SFD(nextin).fdbuf.mBuf + point, SFD(nextin).fdbuf.mBufLen - point)) {
+            if(!fd_write(nextout, SFD(nextin).mBuf + point, SFD(nextin).mBufLen - point)) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
         }
         else {
-            if(!fd_write(nextout, SFD(nextin).fdbuf.mBuf, SFD(nextin).fdbuf.mBufLen)) {
+            if(!fd_write(nextout, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
@@ -1920,7 +1920,7 @@ BOOL cmd_add(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -1966,7 +1966,7 @@ BOOL cmd_del(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             number = 1;
         }
 
-        const int len = str_kanjilen(code, SFD(nextin).fdbuf.mBuf);
+        const int len = str_kanjilen(code, SFD(nextin).mBuf);
 
         if(index < 0) {
             index += len;
@@ -1977,15 +1977,15 @@ BOOL cmd_del(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             if(index < 0) index = 0;
         }
 
-        int point = str_kanjipos2pointer(code, SFD(nextin).fdbuf.mBuf, index) - SFD(nextin).fdbuf.mBuf;
+        int point = str_kanjipos2pointer(code, SFD(nextin).mBuf, index) - SFD(nextin).mBuf;
         
-        if(!fd_write(nextout, SFD(nextin).fdbuf.mBuf, point)) {
+        if(!fd_write(nextout, SFD(nextin).mBuf, point)) {
             err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
         if(index + number < len) {
-            char* point = str_kanjipos2pointer(code, SFD(nextin).fdbuf.mBuf, index + number);
+            char* point = str_kanjipos2pointer(code, SFD(nextin).mBuf, index + number);
             if(!fd_write(nextout, point, strlen(point))) {
                 err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -1993,7 +1993,7 @@ BOOL cmd_del(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
 
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -2023,7 +2023,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
 
     if(runinfo->mFilter && command->mArgsNumRuntime > 1 && command->mBlocksNum <= command->mArgsNumRuntime-1) {
-        if(SFD(nextin).fdbuf.mBufLen == 0) {
+        if(SFD(nextin).mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
         else {
@@ -2051,7 +2051,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     return FALSE;
                 }
 
-                const int kanjilen = str_kanjilen(code, SFD(nextin).fdbuf.mBuf);
+                const int kanjilen = str_kanjilen(code, SFD(nextin).mBuf);
                 if(kanjilen > 0) {
                     int first = atoi(buf);
                     int second = atoi(buf2);
@@ -2078,12 +2078,12 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     if(code == kByte) {
                         int k;
                         for(k=0; k<kanjilen; k++) {
-                            array[k] = SFD(nextin).fdbuf.mBuf + k;
+                            array[k] = SFD(nextin).mBuf + k;
                         }
-                        array[k] = SFD(nextin).fdbuf.mBuf + k;
+                        array[k] = SFD(nextin).mBuf + k;
                     }
                     else if(code == kUtf8) {
-                        char* p = SFD(nextin).fdbuf.mBuf;
+                        char* p = SFD(nextin).mBuf;
 
                         int k;
                         for(k=0; k<kanjilen; k++) {
@@ -2099,7 +2099,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         array[k] = p;
                     }
                     else {
-                        char* p = SFD(nextin).fdbuf.mBuf;
+                        char* p = SFD(nextin).mBuf;
 
                         int k;
                         for(k=0; k<kanjilen; k++) {
@@ -2111,7 +2111,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     }
 
                     if(first < second) {
-                        sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+                        sObject* nextin2 = FD_NEW_STACK();
 
                         int j;
                         for(j=first; j<=second; j++) {
@@ -2134,7 +2134,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                                 runinfo->mRCode = rcode;
                             }
                             else {
-                                if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen)) 
+                                if(!fd_write(nextout, SFD(nextin2).mBuf, SFD(nextin2).mBufLen)) 
                                 {
                                     err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -2146,7 +2146,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         }
                     }
                     else {
-                        sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+                        sObject* nextin2 = FD_NEW_STACK();
 
                         int j;
                         for(j=first; j>=second; j--) {
@@ -2169,7 +2169,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                                 runinfo->mRCode = rcode;
                             }
                             else {
-                                if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen)) 
+                                if(!fd_write(nextout, SFD(nextin2).mBuf, SFD(nextin2).mBufLen)) 
                                 {
                                     err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
@@ -2185,7 +2185,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
             }
             else {
-                const int len = str_kanjilen(code, SFD(nextin).fdbuf.mBuf);
+                const int len = str_kanjilen(code, SFD(nextin).mBuf);
                 int num = atoi(arg);
 
                 if(num < 0) {
@@ -2197,9 +2197,9 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     if(num < 0) num = 0;
                 }
 
-                sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+                sObject* nextin2 = FD_NEW_STACK();
 
-                char* str = str_kanjipos2pointer(code, SFD(nextin).fdbuf.mBuf, num);
+                char* str = str_kanjipos2pointer(code, SFD(nextin).mBuf, num);
                 char* str2 = str_kanjipos2pointer(code, str, 1);
                 if(!fd_write(nextin2, str, str2 -str)) {
                     err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
@@ -2216,7 +2216,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     runinfo->mRCode = rcode;
                 }
                 else {
-                    if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen)) 
+                    if(!fd_write(nextout, SFD(nextin2).mBuf, SFD(nextin2).mBufLen)) 
                     {
                         err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
