@@ -18,8 +18,8 @@ int completion_gc_children_mark(sObject* self)
 
     sObject* block = SCOMPLETION(self).mBlock;
     if(block) {
-        if((block->mFlg & GC_MARK) == 0) {
-            block->mFlg |= GC_MARK;
+        if(IS_MARKED(block) == 0) {
+            SET_MARK(block);
             count++;
             count += object_gc_children_mark(block);
         }
