@@ -25,7 +25,6 @@ sObject* fun_new_from_gc(sObject* parent, BOOL user_object, BOOL no_stackframe)
 
    SFUN(self).mArgBlocks = NULL;
 
-   SFUN(self).mRunInfo = NULL;
    SFUN(self).mOptions = MALLOC(sizeof(option_hash_it)*XYZSH_OPTION_MAX);
    memset(SFUN(self).mOptions, 0, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
 
@@ -45,7 +44,6 @@ sObject* fun_new_from_stack(sObject* parent)
    SFUN(self).mLocalObjects = NULL;
    SFUN(self).mArgBlocks = NULL;
 
-   SFUN(self).mRunInfo = NULL;
    SFUN(self).mOptions = MALLOC(sizeof(option_hash_it)*XYZSH_OPTION_MAX);
    memset(SFUN(self).mOptions, 0, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
 
@@ -65,7 +63,6 @@ sObject* fun_clone_from_stack_block_to_gc(sObject* block, BOOL user_object, sObj
    SFUN(self).mLocalObjects = NULL;
    SFUN(self).mArgBlocks = NULL;
 
-   SFUN(self).mRunInfo = NULL;
    SFUN(self).mOptions = MALLOC(sizeof(option_hash_it)*XYZSH_OPTION_MAX);
    memset(SFUN(self).mOptions, 0, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
 
@@ -85,7 +82,6 @@ sObject* fun_clone_from_stack_block_to_stack(sObject* block, sObject* parent, BO
    SFUN(self).mLocalObjects = NULL;
    SFUN(self).mArgBlocks = NULL;
 
-   SFUN(self).mRunInfo = NULL;
    SFUN(self).mOptions = MALLOC(sizeof(option_hash_it)*XYZSH_OPTION_MAX);
    memset(SFUN(self).mOptions, 0, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
 
@@ -120,8 +116,8 @@ int fun_gc_children_mark(sObject* self)
 
     sObject* block = SFUN(self).mBlock;
     if(block) {
-        if((block->mFlg & GC_MARK) == 0) {
-            block->mFlg |= GC_MARK;
+        if(IS_MARKED(block) == 0) {
+            SET_MARK(block);
             count++;
             count += object_gc_children_mark(block);
         }
@@ -129,8 +125,8 @@ int fun_gc_children_mark(sObject* self)
 
     sObject* parent = SFUN(self).mParent;
     if(parent) {
-        if((parent->mFlg & GC_MARK) == 0) {
-            parent->mFlg |= GC_MARK;
+        if(IS_MARKED(parent) == 0) {
+            SET_MARK(parent);
             count++;
             count += object_gc_children_mark(parent);
         }
@@ -138,8 +134,8 @@ int fun_gc_children_mark(sObject* self)
 
     sObject* lobjects = SFUN(self).mLocalObjects;
     if(lobjects) {
-        if((lobjects->mFlg & GC_MARK) == 0) {
-            lobjects->mFlg |= GC_MARK;
+        if(IS_MARKED(lobjects) == 0) {
+            SET_MARK(lobjects);
             count++;
             count += object_gc_children_mark(lobjects);
         }
@@ -147,8 +143,8 @@ int fun_gc_children_mark(sObject* self)
 
     sObject* arg_blocks = SFUN(self).mArgBlocks;
     if(arg_blocks) {
-        if((arg_blocks->mFlg & GC_MARK) == 0) {
-            arg_blocks->mFlg |= GC_MARK;
+        if(IS_MARKED(arg_blocks) == 0) {
+            SET_MARK(arg_blocks);
             count++;
             count += object_gc_children_mark(arg_blocks);
         }
