@@ -13,16 +13,13 @@ sObject* gRootObject;
 sObject* gCompletionObject;
 sObject* gXyzshObject;
 sObject* gCurrentObject;
-sObject* gMemChecker;
 sObject* gStackFrames;
 
 #define SLOT_SIZE 64
 
 static void object_delete(sObject* obj)
 {
-    if(obj->mUserObject) memchecker_erase(gMemChecker, obj);
-
-    switch(obj->mFlg & 0xff) {
+    switch(TYPE(obj)) {
     case T_STRING:
         string_delete_gc(obj);
         break;
@@ -70,10 +67,6 @@ static void object_delete(sObject* obj)
         uobject_delete_gc(obj);
         break;
 
-    case T_MEMCHECKER:
-        fprintf(stderr, "unexpected err on object_delete at gc.c");
-        exit(1);
-
     case T_EXTOBJ:
         SEXTOBJ(obj).mFreeFun(SEXTOBJ(obj).mObject);
         break;
@@ -141,7 +134,7 @@ static int sweep()
         sObject* p = gPool[i];
         int j;
         for(j=0; j<SLOT_SIZE; j++) {
-           if((p[j].mFlg & 0xff) != 0 && !(p[j].mFlg & GC_MARK)) {
+           if(TYPE(p + j) != 0 && !IS_MARKED(p + j)) {
                 object_delete(p + j);
 
                 memset(p + j, 0, sizeof(sObject));
@@ -157,10 +150,32 @@ static int sweep()
     return count;
 }
 
+BOOL gc_valid_object(sObject* object)
+{
+    int i;
+    for(i=0; i<gPoolSize; i++) {
+        if(object >= gPool[i] && object < gPool[i] + SLOT_SIZE) {
+            ulong n = ((ulong)object - (ulong)gPool[i]) % (ulong)sizeof(sObject);
+            if(n == 0) {
+                if(TYPE(object) > 0 && TYPE(object) < T_TYPE_MAX) {
+                    return TRUE;
+                }
+                else {
+                    return FALSE;
+                }
+
+            }
+            else {
+                return FALSE;
+            }
+        }
+    }
+
+    return FALSE;
+}
+
 void gc_init(int pool_size)
 {
-   gMemChecker = MEMCHECKER_NEW_STACK(128);
-
     gPoolSize = pool_size;
     gPool = (sObject**)MALLOC(sizeof(sObject*)*gPoolSize);
     memset(gPool, 0, sizeof(sObject*)*gPoolSize);
@@ -222,7 +237,7 @@ void gc_final()
         sObject* p = gPool[i];
         int j;
         for(j=0; j<SLOT_SIZE; j++) {
-            if(p[j].mFlg & 0xff) {
+            if(TYPE(p + j)) {
                 object_delete(p + j);
             }
         }
@@ -239,15 +254,18 @@ static int mark()
         sObject* p = gPool[i];
         int j;
         for(j=0; j<SLOT_SIZE; j++) {
-            p[j].mFlg &= ~GC_MARK;
+            CLEAR_MARK(p + j);
         }
     }
     
     /// mark all objects
-    gRootObject->mFlg |= GC_MARK;
-    int count = uobject_gc_children_mark(gRootObject);
+    int count = 0;
+    SET_MARK(gRootObject);
+    count++;
+    count += uobject_gc_children_mark(gRootObject);
 
-    gXyzshObject->mFlg |= GC_MARK;
+    SET_MARK(gXyzshObject);
+    count++;
     count += uobject_gc_children_mark(gXyzshObject);
 
     return count;
@@ -311,10 +329,11 @@ sObject* gc_get_free_object(int kind, BOOL user_object)
     sObject* result = gFreeObjectHead;
     gFreeObjectHead = gFreeObjectHead->mNextFreeObject;
 
-    result->mUserObject = user_object;
-    if(user_object) memchecker_put(gMemChecker, result, kind);
+    if(user_object) {
+        SET_USER_OBJECT(result);
+    }
 
-    result->mFlg = kind;
+    result->mFlg |= kind;
 
     return result;
 }
