@@ -301,8 +301,8 @@ int list_gc_children_mark(sObject* self)
     for(it= SLIST(self).mEntryIt; it; it=it->mNextIt) {
         sObject* item = it->mItem;
 
-        if(item && (item->mFlg & GC_MARK) == 0) {
-            item->mFlg |= GC_MARK;
+        if(item && IS_MARKED(item) == 0) {
+            SET_MARK(item);
             count ++;
             count += object_gc_children_mark(item);
         }
