@@ -121,7 +121,7 @@ static BOOL read_env(char** p, sBuf* buf, char* sname, int* sline, BOOL expand_q
 {
     (*p)++;
 
-    enum eLineField lf = kLF;
+    eLineField lf = kLF;
 
     BOOL double_dollar;
     if(**p == '$') {
