@@ -259,8 +259,8 @@ static char* user_completion(const char* text, int stat)
         gCompletionArray = VECTOR_NEW_STACK(16);
 
         int i;
-        for(i=0; i<vector_count(SFD(gUserCompletionNextout).fdbuf.mLines); i++) {
-            sObject* candidate = STRING_NEW_STACK(vector_item(SFD(gUserCompletionNextout).fdbuf.mLines, i));
+        for(i=0; i<vector_count(SFD(gUserCompletionNextout).mLines); i++) {
+            sObject* candidate = STRING_NEW_STACK(vector_item(SFD(gUserCompletionNextout).mLines, i));
             string_chomp(candidate);
             vector_add(gCompletionArray, string_c_str(candidate));
         }
@@ -562,12 +562,12 @@ char** readline_on_complete(const char* text, int start, int end)
                 }
             }
             else if(ucompletion && TYPE(ucompletion) == T_COMPLETION) {
-                sObject* nextin = FD_NEW_STACK(kFDKindBuf, 0);
+                sObject* nextin = FD_NEW_STACK();
                 if(!fd_write(nextin, string_c_str(cmdline), string_length(cmdline))) {
                     stack_end_stack();
                     return NULL;
                 }
-                sObject* nextout = FD_NEW_STACK(kFDKindBuf, 0);
+                sObject* nextout = FD_NEW_STACK();
 
                 sObject* fun = FUN_NEW_STACK(NULL);
                 sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
@@ -612,7 +612,7 @@ char** readline_on_complete(const char* text, int start, int end)
                 (void)vector_pop_back(gStackFrames);
                 readline_signal();
 
-                enum eLineField lf;
+                eLineField lf;
                 if(fd_guess_lf(nextout, &lf)) {
                     fd_split(nextout, lf);
                 } else {
@@ -804,7 +804,7 @@ BOOL cmd_readline_insert_text(sObject* nextin, sObject* nextout, sRunInfo* runin
     sCommand* command = runinfo->mCommand;
 
     if(runinfo->mFilter) {
-        (void)rl_insert_text(SFD(nextin).fdbuf.mBuf);
+        (void)rl_insert_text(SFD(nextin).mBuf);
         puts("");
         rl_forced_update_display();
 
@@ -868,7 +868,7 @@ static int readline_macro(int count, int key)
 {
     stack_start_stack();
 
-    sObject* nextout2 = FD_NEW_STACK(kFDKindBuf, 0);
+    sObject* nextout2 = FD_NEW_STACK();
 
     int rcode = 0;
     sObject* block = BLOCK_NEW_STACK();
@@ -882,7 +882,7 @@ static int readline_macro(int count, int key)
         //uobject_init(stackframe);
         SFUN(fun).mLocalObjects = stackframe;
 
-        sObject* nextin2 = FD_NEW_STACK(kFDKindBuf, 0);
+        sObject* nextin2 = FD_NEW_STACK();
 
         (void)fd_write(nextin2, rl_line_buffer, rl_point);
 
@@ -909,7 +909,7 @@ static int readline_macro(int count, int key)
         fprintf(stderr, "%s", string_c_str(gErrMsg));
     }
 
-    rl_insert_text(SFD(nextout2).fdbuf.mBuf);
+    rl_insert_text(SFD(nextout2).mBuf);
     puts("");
     rl_forced_update_display();
     stack_end_stack();
