@@ -29,6 +29,21 @@ static sObject* gObjectsInPipe;
 
 static sObject* gRunningObjects;
 
+sRunInfo* gRunInfoOfRunningObject;
+
+BOOL contained_in_pipe(sObject* object)
+{
+    BOOL found = FALSE;
+    int j;
+    for(j=0; j<vector_count(gObjectsInPipe); j++) {
+        if(object == vector_item(gObjectsInPipe, j)) {
+            found = TRUE;
+        }
+    }
+
+    return found;
+}
+
 BOOL add_object_to_objects_in_pipe(sObject* object, sRunInfo* runinfo, sCommand* command)
 {
     vector_add(gObjectsInPipe, object);
@@ -41,7 +56,7 @@ BOOL add_object_to_objects_in_pipe(sObject* object, sRunInfo* runinfo, sCommand*
     return TRUE;
 }
 
-enum eLineField gLineField;
+eLineField gLineField;
 enum eKanjiCode gKanjiCode;
 
 void (*xyzsh_job_done)(int job_num, char* job_title);
@@ -51,9 +66,9 @@ sObject* gJobs;
 void run_init(enum eAppType app_type)
 {
     gAppType = app_type;
-    gStdin = FD_NEW_STACK(kFDKindBuf, 0);
-    gStdout = FD_NEW_STACK(kFDKindBuf, 0);
-    gStderr = FD_NEW_STACK(kFDKindBuf, 0);
+    gStdin = FD_NEW_STACK();
+    gStdout = FD_NEW_STACK();
+    gStderr = FD_NEW_STACK();
     gJobs = VECTOR_NEW_GC(16, FALSE);
     uobject_put(gXyzshObject, "_jobs", gJobs);
 
@@ -62,7 +77,9 @@ void run_init(enum eAppType app_type)
     gLineField = kLF;
     gKanjiCode = kByte;
 
-    gGlobalPipe = FD_NEW_STACK(kFDKindBuf, 0);
+    gRunInfoOfRunningObject = NULL;
+
+    gGlobalPipe = FD_NEW_STACK();
 
     gObjectsInPipe = VECTOR_NEW_GC(10, FALSE);
     uobject_put(gXyzshObject, "_objects_in_pipe", gObjectsInPipe);
@@ -154,7 +171,7 @@ static void nextin_writer(pid_t pid, sObject* nextin, int* pipeinfds, int* pipeo
         }
         (void)close(pipeinfds[0]);
 
-        if(!bufsiz_write(pipeinfds[1], SFD(nextin).fdbuf.mBuf, SFD(nextin).fdbuf.mBufLen)) {
+        if(!bufsiz_write(pipeinfds[1], SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
             if(errno != EPIPE ) {
                 perror("write memory pipe");
                 exit(1);
@@ -444,11 +461,11 @@ static BOOL run_external_command(char* program, sObject* nextin, sObject* nextou
     int nextout2;
     int nexterr2;
 
-    if(nextin == gStdin && SFD(gStdin).fdbuf.mBufLen == 0) {
+    if(nextin == gStdin && SFD(gStdin).mBufLen == 0) {
         nextin2 = 0;
     }
-    else if(SFD(nextin).mKind == kFDKindFD) {
-        nextin2 = SFD(nextin).fd.mFD;
+    else if(TYPE(nextin) == T_FD2) {
+        nextin2 = SFD2(nextin).mFD;
     }
     else {
         if(pipe(pipeinfds) < 0) {
@@ -461,8 +478,8 @@ static BOOL run_external_command(char* program, sObject* nextin, sObject* nextou
         nextout2 = 1;
         nexterr2 = 2;
     }
-    else if(SFD(nextout).mKind == kFDKindFD) {
-        nextout2 = SFD(nextout).fd.mFD;
+    else if(TYPE(nextout) == T_FD2) {
+        nextout2 = SFD2(nextout).mFD;
 
         if(pipe(pipeerrfds) < 0) {
             perror("pipe");
@@ -547,10 +564,10 @@ if(1) {
         /// Therefore xyzsh can't waitpid and deadlock.
         /// Avoid this, xyzsh is ready for a writer process to write buffer to the xyzsh.
         pid_t nextin_reader_pid = -1;
-        if(SFD(nextin).mKind != kFDKindFD && nextin2 != 0) {
+        if(TYPE(nextin) != T_FD2 && nextin2 != 0) {
             nextin_writer(pgroup, nextin, pipeinfds, pipeoutfds, pipeerrfds, runinfo, program, &nextin_reader_pid);
         }
-        if(SFD(nextout).mKind != kFDKindFD && nextout2 != 1) {
+        if(TYPE(nextout) != T_FD2 && nextout2 != 1) {
             (void)close(pipeoutfds[1]);
             if(!nextout_reader(nextout, pipeoutfds, runinfo, program)) {
                 // wait everytime
@@ -578,8 +595,8 @@ if(1) {
 BOOL run_function(sObject* fun, sObject* nextin, sObject* nextout, sRunInfo* runinfo, char** argv, int argc, sObject** blocks, int blocks_num)
 {
     sObject* local_objects = SFUN(fun).mLocalObjects;
-    sRunInfo* runinfo2 = SFUN(fun).mRunInfo;
-    SFUN(fun).mRunInfo = runinfo;
+    sRunInfo* runinfo2 = gRunInfoOfRunningObject;
+    gRunInfoOfRunningObject = runinfo;
 
     BOOL no_stackframe = SFUN(fun).mFlags & FUN_FLAGS_NO_STACKFRAME;
 
@@ -643,6 +660,7 @@ BOOL run_function(sObject* fun, sObject* nextin, sObject* nextout, sRunInfo* run
             runinfo->mRCode = rcode;
             SFUN(fun).mLocalObjects = local_objects;
             (void)vector_pop_back(gStackFrames);
+            gRunInfoOfRunningObject = runinfo2;
             return FALSE;
         }
     }
@@ -653,7 +671,7 @@ BOOL run_function(sObject* fun, sObject* nextin, sObject* nextout, sRunInfo* run
 
     SFUN(fun).mLocalObjects = local_objects;
     SFUN(fun).mArgBlocks = arg_blocks;
-    SFUN(fun).mRunInfo = runinfo2;
+    gRunInfoOfRunningObject = runinfo2;
 
     return TRUE;
 }
@@ -878,11 +896,6 @@ static BOOL redirect_ready(sObject** nextout, sObject** nextin, int* opened_fd,
 
         switch(command->mRedirects[i] & REDIRECT_KIND) {
             case REDIRECT_IN:
-                if(SFD(*nextin).mKind == kFDKindBuf) {
-                    FREE(SFD(*nextin).fdbuf.mBuf);
-                }
-
-                SFD(*nextin).mKind = kFDKindBuf;
                 fd = open(command->mRedirectsFileNamesRuntime[i], O_RDONLY);
                 if(fd < 0) {
                     char buf[BUFSIZ];
@@ -897,12 +910,10 @@ static BOOL redirect_ready(sObject** nextout, sObject** nextin, int* opened_fd,
                     err_msg(buf, runinfo->mSName, runinfo->mSLine, "");
                     return FALSE;
                 }
-
-                SFD(*nextin).fdbuf.mBuf = result;
-                SFD(*nextin).fdbuf.mBufSize = result_size;
-                SFD(*nextin).fdbuf.mBufLen = result_len;
-
                 (void)close(fd);
+
+                ASSERT(TYPE(*nextin) == T_FD);
+                fd_put(*nextin, MANAGED result, result_size, result_len);
                 break;
 
             case REDIRECT_APPEND:
@@ -914,7 +925,7 @@ static BOOL redirect_ready(sObject** nextout, sObject** nextin, int* opened_fd,
                         err_msg(buf, runinfo->mSName, runinfo->mSLine, "");
                         return FALSE;
                     }
-                    *nextout = FD_NEW_STACK(kFDKindFD, fd);
+                    *nextout = FD2_NEW_STACK(fd);
 
                     *opened_fd = fd;
                 }
@@ -929,7 +940,7 @@ static BOOL redirect_ready(sObject** nextout, sObject** nextin, int* opened_fd,
                         err_msg(buf, runinfo->mSName, runinfo->mSLine, "");
                         return FALSE;
                     }
-                    *nextout = FD_NEW_STACK(kFDKindFD, fd);
+                    *nextout = FD2_NEW_STACK(fd);
 
                     *opened_fd = fd;
                 }
@@ -959,7 +970,7 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
     sObject* nextin;
     if(statment->mFlags & STATMENT_CONTEXTPIPE) {
         /// read stdin ///
-        if(pipein == gStdin && SFD(gStdin).fdbuf.mBufLen == 0 && !isatty(0)) {
+        if(pipein == gStdin && SFD(gStdin).mBufLen == 0 && !isatty(0)) {
             if(!stdin_read_out()) {
                 sCommand* command = runinfo->mCommand;
                 if(command) {
@@ -981,19 +992,19 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
         }
         /// line context pipe ///
         else {
-            nextin = FD_NEW_STACK(kFDKindBuf, 0);
-            enum eLineField lf;
+            nextin = FD_NEW_STACK();
+            eLineField lf;
             if(fd_guess_lf(pipein, &lf)) {
                 fd_split(pipein, lf);
             } else {
                 fd_split(pipein, kLF);
             }
-            if(line_number < 0) line_number += vector_count(SFD(pipein).fdbuf.mLines)+1;
+            if(line_number < 0) line_number += vector_count(SFD(pipein).mLines)+1;
             if(line_number < 0) line_number = 0;
-            if(line_number > vector_count(SFD(pipein).fdbuf.mLines)) line_number = vector_count(SFD(pipein).fdbuf.mLines);
+            if(line_number > vector_count(SFD(pipein).mLines)) line_number = vector_count(SFD(pipein).mLines);
             int i;
-            for(i=SFD(pipein).fdbuf.mReadedLineNumber; i<vector_count(SFD(pipein).fdbuf.mLines) && i-SFD(pipein).fdbuf.mReadedLineNumber<line_number; i++) {
-                char* line = vector_item(SFD(pipein).fdbuf.mLines, i);
+            for(i=SFD(pipein).mReadedLineNumber; i<vector_count(SFD(pipein).mLines) && i-SFD(pipein).mReadedLineNumber<line_number; i++) {
+                char* line = vector_item(SFD(pipein).mLines, i);
                 if(!fd_write(nextin, line, strlen(line))) {
                     sCommand* command = runinfo->mCommand;
                     if(command) {
@@ -1006,12 +1017,12 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
                     return FALSE;
                 }
             }
-            SFD(pipein).fdbuf.mReadedLineNumber += line_number;
+            SFD(pipein).mReadedLineNumber += line_number;
         }
     }
     else if(statment->mFlags & STATMENT_GLOBALPIPEIN) {
-        nextin = FD_NEW_STACK(kFDKindBuf, 0);
-        if(!fd_write(nextin, SFD(gGlobalPipe).fdbuf.mBuf, SFD(gGlobalPipe).fdbuf.mBufLen)) {
+        nextin = FD_NEW_STACK();
+        if(!fd_write(nextin, SFD(gGlobalPipe).mBuf, SFD(gGlobalPipe).mBufLen)) {
             sCommand* command = runinfo->mCommand;
             if(command) {
                 err_msg("signal interrupt12", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
@@ -1049,6 +1060,8 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
             return TRUE;
         }
         
+        ASSERT(TYPE(nextin) == T_FD);
+
         if(nextout == NULL) {
             if(last_program) {
                 if(statment->mFlags & STATMENT_GLOBALPIPEOUT) {
@@ -1063,7 +1076,7 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
                 }
             }
             else {
-                nextout = FD_NEW_STACK(kFDKindBuf, 0);
+                nextout = FD_NEW_STACK();
             }
         }
 
@@ -1226,8 +1239,8 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
 
         if(opened_fd != -1) redirect_finish(opened_fd);
 
-        if(SFD(nextout).mKind == kFDKindFD) {
-            nextin = FD_NEW_STACK(kFDKindBuf, 0);
+        if(TYPE(nextout) == T_FD2) {
+            nextin = FD_NEW_STACK();
         }
         else {
             nextin = nextout;
@@ -1549,6 +1562,7 @@ BOOL bufsiz_read(int fd, ALLOC char** result, int* result_len, int* result_size)
                 source = REALLOC(source, source_size);
             }
             strcat(source, buf);
+            source_len += size;
             break;
         }
         else {
