@@ -337,7 +337,7 @@ void string_toupper(sObject* self, enum eKanjiCode code)
     }
 }
 
-BOOL string_pomch(sObject* str, enum eLineField lf)
+BOOL string_pomch(sObject* str, eLineField lf)
 {
     char* s = string_c_str(str);
     const int len = strlen(s);
