@@ -326,8 +326,8 @@ int uobject_gc_children_mark(sObject* self)
     while(it) {
         sObject* item = it->mItem;
 
-        if(item && (item->mFlg & GC_MARK) == 0) {
-            item->mFlg |= GC_MARK;
+        if(item && IS_MARKED(item) == 0) {
+            SET_MARK(item);
             count++;
 
             count += object_gc_children_mark(item);
