@@ -231,8 +231,8 @@ int vector_gc_children_mark(sObject* self)
     for(i=0; i<SVECTOR(self).mCount; i++) {
         sObject* item = SVECTOR(self).mTable[i];
 
-        if(item && (item->mFlg & GC_MARK) == 0) {
-            item->mFlg |= GC_MARK;
+        if(item && IS_MARKED(item) == 0) {
+            SET_MARK(item);
             count++;
 
             count += object_gc_children_mark(item);
