@@ -21,7 +21,7 @@ void sCommand_delete(sCommand* self);
 
 void sCommand_add_arg_to_command(sCommand* self, MANAGED char* buf, int env, int glob);
 BOOL sCommand_add_message(sCommand* self, MANAGED char* message);
-void sCommand_add_env_block(sCommand* self, sObject* block, BOOL double_dollar, enum eLineField lf);
+void sCommand_add_env_block(sCommand* self, sObject* block, BOOL double_dollar, eLineField lf);
 void sCommand_add_env(sCommand* self, MANAGED char* name, MANAGED char* key, BOOL key_env, BOOL double_dollar);
 void sCommand_add_redirect_to_command(sCommand* self, MANAGED char* name, BOOL env, BOOL glob, int redirect);
 
