@@ -47,7 +47,7 @@ void string_erase(sObject* obj, int pos, int len);
 void string_toupper(sObject* self, enum eKanjiCode code);
 void string_tolower(sObject* self, enum eKanjiCode code);
 
-BOOL string_pomch(sObject* str, enum eLineField lf);
+BOOL string_pomch(sObject* str, eLineField lf);
 BOOL string_chomp(sObject* str);
 
 unsigned int string_size(sObject* self);
