@@ -21,6 +21,10 @@
 //#define SPACE                   // indicate that a memory which is enough to use
 #define MANAGED                 // indicate that a memory which is managed inside the function or object
 
+typedef unsigned char uchar;
+typedef unsigned int uint;
+typedef unsigned long ulong;
+
 #include <unistd.h>
 
 enum eCommandKind { 
@@ -63,8 +67,14 @@ enum eCommandKind {
     kCommandMax
 };
 
-enum eLineField { kLF, kCRLF, kCR, kBel };
-extern enum eLineField gLineField;
+#define kLF 0x01
+#define kCRLF 0x02
+#define kCR 0x03
+#define kBel 0x04
+
+typedef char eLineField;
+
+extern eLineField gLineField;
 extern enum eKanjiCode gKanjiCode;
 
 enum eAppType { kATOptC, kATXApp, kATConsoleApp };
@@ -129,28 +139,19 @@ typedef struct {
    int mCount;
 } vector_obj;
 
-#define kFDKindFD 1
-#define kFDKindBuf 2
+typedef struct {
+    char* mBuf;
+    int mBufSize;
+    int mBufLen;
+
+    struct _sObject* mLines;
+    eLineField mLinesLineField;
+    unsigned int mReadedLineNumber;
+} fd_obj;
 
 typedef struct {
-    int mKind;
-
-    union {
-        struct {
-            unsigned int mFD;
-        } fd;
-
-        struct {
-            char* mBuf;
-            int mBufSize;
-            int mBufLen;
-
-            struct _sObject* mLines;
-            enum eLineField mLinesLineField;
-            unsigned int mReadedLineNumber;
-        } fdbuf;
-    };
-} fd_obj;
+    uint mFD;
+} fd2_obj;
 
 typedef struct {
     char* mPath;
@@ -195,7 +196,7 @@ typedef struct {
         };
         struct {
             struct _sObject* mBlock;
-            enum eLineField mLineField;
+            eLineField mLineField;
         };
     };
 } sEnv;
@@ -220,10 +221,6 @@ typedef struct {
     int mArgsNum;
     int mArgsSize;
 
-    char** mArgsRuntime;
-    int mArgsNumRuntime;
-    int mArgsSizeRuntime;
-
     sEnv* mEnvs;
     int mEnvsNum;
     int mEnvsSize;
@@ -237,12 +234,16 @@ typedef struct {
     int mRedirectsNum;
     int mRedirectsSize;
 
-    char** mRedirectsFileNamesRuntime; //runtime
-
     option_hash_it mOptions[XYZSH_OPTION_MAX];  // open adressing hash
 
     char* mMessages[XYZSH_MESSAGES_MAX];
     int mMessagesNum;
+
+    char** mArgsRuntime;  // runtime info
+    int mArgsNumRuntime;
+    int mArgsSizeRuntime;
+
+    char** mRedirectsFileNamesRuntime; //runtime info
 } sCommand;
 
 typedef struct {
@@ -281,16 +282,13 @@ struct _sRunInfo;
 typedef struct
 {
     struct _sObject* mBlock;
-
     struct _sObject* mParent;
 
     struct _sObject* mLocalObjects;
     struct _sObject* mArgBlocks;
-
     option_hash_it* mOptions;
-    struct _sRunInfo* mRunInfo;
 
-    char mFlags;
+    uchar mFlags;
 } fun_obj;
 
 typedef fun_obj class_obj;
@@ -334,24 +332,6 @@ typedef struct {
    struct _sObject* mParent;
 } uobject_obj;
 
-typedef struct _memchecker_it {
-   void* mKey;
-   
-   int mItem;
-   struct _memchecker_it* mCollisionIt;
-
-   struct _memchecker_it* mNextIt;
-} memchecker_it;
-
-typedef struct {
-   memchecker_it** mTable;
-   int mTableSize;
-
-   memchecker_it* mEntryIt;
-
-   int mCounter;
-} memchecker_obj;
-
 struct _sRunInfo;
 
 typedef int (*fExtObjMarkFun)(struct _sObject* self);
@@ -370,7 +350,17 @@ typedef struct {
     struct _sObject* mBlock;
 } completion_obj;
 
-#define GC_MARK 0x80000000
+#define GC_MARK 0x8000
+
+#define SOBJ_USER_OBJECT 0x100
+#define IS_USER_OBJECT(o) ((o)->mFlg & SOBJ_USER_OBJECT)
+#define SET_USER_OBJECT(o) ((o)->mFlg |= SOBJ_USER_OBJECT)
+
+#define IS_MARKED(o) ((o)->mFlg & GC_MARK)
+#define SET_MARK(o) ((o)->mFlg |= GC_MARK)
+
+#define TYPE(o) ((o)->mFlg & 0xFF)
+#define CLEAR_MARK(o) ((o)->mFlg &= ~GC_MARK)
 
 #define T_STRING 1
 #define T_VECTOR 2
@@ -379,19 +369,19 @@ typedef struct {
 #define T_NFUN 5
 #define T_BLOCK 6
 #define T_FD 7
-#define T_JOB 8
-#define T_UOBJECT 9
-#define T_MEMCHECKER 10
+#define T_FD2 8
+#define T_JOB 9
+#define T_UOBJECT 10
 #define T_FUN 11
 #define T_CLASS 12
 #define T_EXTPROG 13
 #define T_COMPLETION 14
 #define T_EXTOBJ 15
+#define T_TYPE_MAX 16
 
 typedef struct _sObject {
-    int mFlg;                         // contains a kind of the above and a mark flag
+    int mFlg;         // contains a kind of the above and a mark flag, user object flag
     struct _sObject* mNextFreeObject;
-    BOOL mUserObject;
 
     union {
         string_obj uString;
@@ -399,11 +389,11 @@ typedef struct _sObject {
         hash_obj uHash;
         list_obj uList;
         fd_obj uFd;
+        fd2_obj uFd2;
         job_obj uJob;
         struct block_obj uBlock;
 
         uobject_obj uUObject;
-        memchecker_obj uMemchecker;
         nfun_obj uNativeFun;
         fun_obj uFunction;
         class_obj uClass;
@@ -413,8 +403,6 @@ typedef struct _sObject {
     };
 } sObject;
 
-#define TYPE(o) (o->mFlg & 0xFF)
-
 #define SSTRING(o) (o)->uString
 #define SVECTOR(o) (o)->uVector
 #define SHASH(o) (o)->uHash
@@ -422,9 +410,9 @@ typedef struct _sObject {
 #define SBLOCK(o) (o)->uBlock
 #define SNFUN(o) (o)->uNativeFun
 #define SFD(o) (o)->uFd
+#define SFD2(o) (o)->uFd2
 #define SJOB(o) (o)->uJob
 #define SUOBJECT(o) (o)->uUObject
-#define SMEMCHECKER(o) (o)->uMemchecker
 #define SFUN(o) (o)->uFunction
 #define SCLASS(o) (o)->uClass
 #define SEXTPROG(o) (o)->uExternalProg
@@ -442,6 +430,7 @@ void stack_end_stack();
 sObject* stack_get_free_object(int kind);
 int stack_slot_size();
 int stack_page_size();
+BOOL stack_valid_object(sObject* object);
 
 #include <xyzsh/debug.h>
 #include <xyzsh/hash.h>
@@ -481,15 +470,6 @@ void external_prog_delete_gc();
 
 #define EXTPROG_NEW_GC(o, o2) external_prog_new_from_gc(o, o2)
 
-sObject* memchecker_new_from_stack(int size);
-void memchecker_delete_stack(sObject* self);
-
-#define MEMCHECKER_NEW_STACK(o) memchecker_new_from_stack(o)
-
-void memchecker_put(sObject* self, void* key, int item);
-BOOL memchecker_erase(sObject* self, void* key);
-int memchecker_item(sObject* self, void* key);
-
 sObject* completion_new_from_gc(sObject* block, BOOL user_object);
 int completion_gc_children_mark(sObject* self);
 
@@ -522,11 +502,15 @@ int class_gc_children_mark(sObject* self);
 
 sObject* fd_new_from_stack();
 void fd_delete_stack(sObject* self);
-#define FD_NEW_STACK(kind, fd) fd_new_from_stack(kind, fd)
+#define FD_NEW_STACK() fd_new_from_stack()
 BOOL fd_write(sObject* self, char* str, int size);
 
-void fd_split(sObject* self, enum eLineField lf);
-BOOL fd_guess_lf(sObject* self, enum eLineField* lf);
+void fd_split(sObject* self, eLineField lf);
+BOOL fd_guess_lf(sObject* self, eLineField* lf);
+void fd_put(sObject* self, MANAGED char* buf, int buf_size, int buf_len);
+
+sObject* fd2_new_from_stack(uint fd);
+#define FD2_NEW_STACK(o) fd2_new_from_stack(o)
 
 sObject* job_new_from_gc(char* name, pid_t pgroup, struct termios tty);
 #define JOB_NEW_GC(o, o2, o3) job_new_from_gc(o, o2, o3)
@@ -715,6 +699,7 @@ int gc_slot_size();
 int gc_pool_size();
 int gc_used_objects_num();
 int gc_sweep();
+BOOL gc_valid_object(sObject* object);
 
 BOOL parse(char* p, char* sname, int* sline, sObject* block, sObject** current_object);
 
@@ -737,6 +722,7 @@ extern sObject* gStackFrames;
 extern sObject* gMemChecker;
 extern sObject* gGlobalPipe;
 extern sObject* gInheritObject;
+extern sRunInfo* gRunInfoOfRunningObject;
 
 BOOL bufsiz_write(int fd, char* buf, int buf_len);
 
@@ -785,6 +771,8 @@ void readline_read_history();
 char* xstrncpy(char* src, char* des, int size);
 char* xstrncat(char* src, char* des, int size);
 
+BOOL contained_in_pipe(sObject* object);
+
 //////////////////////////////////////////////////////////////////////
 // xyzsh API
 //////////////////////////////////////////////////////////////////////
